("1 upper case, 1 lower case, 1 digit, and 1 symbol." "1 велика літера, 1 маленька літера, 1 цифра і 1 символ.")
("abbreviated authors" "скорочені автори")
("abbreviation" "абревіатура")
("about" "про")
("about menu" "меню Про")
("above" "зверху")
("abreviated authors" "скорочені автори")
("abstract" "анотація")
("accent" "акцент")
("accent above" "акцент над")
("accent below" "акцент під")
("accept" "прийняти")
("accept all scripts" "дозволити всі скрипти")
("accept during this pass" "прийняти під час цього проходу")
("accept no scripts" "не дозволяти жодних скриптів")
("accept script" "дозволити скрипт")
("access a subtree of @t according to @l." "Отримати доступ до піддерева @t згідно з @l.")
("acknowledge that a document has been written using TeXmacs" "Підтвердити, що документ був написаний за допомогою TeXmacs")
("acknowledgment" "підтвердження")
("acknowledgments" "вдячність")
("a.C.M. computing class" "клас обчислювальної техніки A.C.M.")
("acronym" "акронім")
("action" "дія")
("activate" "активувати")
("activate hidden" "активувати приховане")
("activate once" "активувати один раз")
("activation" "активація")
("active link types" "активні типи посилань")
("acute" "гострий")
("add" "додати")
("add abstract information" "додати абстрактну інформацію")
("add author information" "додати інформацію про автора")
("add backslashed commands in @l to keyboard mapping" "Додати команди з зворотнім слешем в @l до картографування клавіатури")
("add branch after" "додати гілку після")
("add branch before" "додати гілку до")
("add current cursor position into the history" "Додати поточну позицію курсора в історію")
("add entries in @l to the keyboard mapping" "Додати записи з @l до картографування клавіатури")
("add entries in @l to the keyboard wildcard table" "Додати записи з @l до таблиці клавіатурних шаблонів")
("addition" "додаток")
("add other package" "додати інший пакет")
("add package" "додати пакет")
("address" "адреса")
("address block" "блок адреси")
("add style package" "додати пакет стилю")
("add switch after" "додати перемикач після")
("add switch before" "додати перемикач перед")
("add symbols in @l to keyboard mapping" "Додати символи в @l до картографування клавіатури")
("add title information" "додати інформацію про назву")
("adjust" "налаштувати")
("adjust limits" "налаштувати межі")
("advanced" "розширений")
("advanced customizations" "розширені налаштування")
("advanced font customization" "розширена настройка шрифту")
("advanced layout features" "розширені можливості розміщення")
("affiliation" "афіліація")
("after" "після")
("albanian" "албанська")
("algorithm" "алгоритм")
("align cell to the bottom" "вирівняти комірку вниз")
("align cell to the decimal comma" "вирівняти комірку до десяткової коми")
("align cell to the decimal dot" "вирівняти комірку до десяткової крапки")
("align cell to the left" "вирівняти комірку ліворуч")
("align cell to the right" "вирівняти комірку праворуч")
("align cell to the top" "вирівняти комірку вгору")
("aligned" "вирівняно")
("align horizontally at the baseline of a specific column." "Вирівняти горизонтально на базовій лінії вказаного стовпця.")
("alignment" "вирівнювання")
("alignment:" "вирівнювання:")
("alignment of balloon" "вирівнювання кулі")
("align table at axis" "вирівнювати таблицю за осі")
("align table at base of left column" "вирівняти таблицю по базовому рівню лівого стовпця")
("align table at base of middle column" "вирівняти таблицю по базовому рівню середнього стовпця")
("align table at base of origin column" "вирівняти таблицю по базовому рівню вихідного стовпця")
("align table at base of right column" "вирівняти таблицю по базовому рівню правого стовпця")
("align table at fraction bar height" "вирівняти таблицю по висоті риски дробу")
("align table at the base of bottom row" "вирівняти таблицю по базовому рівню нижнього рядка")
("align table at the base of middle row" "вирівняти таблицю по базовому рівню середнього рядка")
("align table at the base of origin row" "вирівняти таблицю по базовому рівню вихідного рядка")
("align table at the base of top row" "вирівняти таблицю по базовому рівню верхнього рядка")
("align table at the bottom" "вирівняти таблицю знизу")
("align table at the center" "вирівняти таблицю по центру")
("align table at the horizontal center" "вирівняти таблицю по горизонталі по центру")
("align table at the left" "вирівняти таблицю ліворуч")
("align table at the top" "вирівняти таблицю зверху")
("align table to the right" "вирівняти таблицю праворуч")
("align text to the left" "вирівняти текст ліворуч")
("align text to the right" "вирівняти текст праворуч")
("align two column table" "Вирівняти двоколонну таблицю")
("align vertically at the baseline of a specific row." "Вирівняти вертикально на базовій лінії вказаного рядка.")
("a list with all help items for @key in language @lan in @cache" "Список з усіма елементами довідки для @key у мові @lan в @cache")
("all" "всі")
("all cells" "всі комірки")
("all data attached to this identity will be lost" "всі дані, повʼязані з цією особою, будуть втрачені")
("allow" "дозволити")
("allow all link types to be followed." "Дозволити слідування всім типам посилань.")
("allow authentification through cryptographic key" "дозволити автентифікацію за допомогою криптографічного ключа")
("allow authentification through password" "дозволити автентифікацію за допомогою пароля")
("allow/disallow the position @what for innermost float." "Дозволити/заборонити позицію @what для найвнутрішнішого плаваючого обʼєкта.")
("allowed extension" "дозволене розширення")
("allowed page height extension" "дозволене розширення висоти сторінки")
("allowed page height extension:" "допустиме збільшення висоти сторінки:")
("allowed page height reduction" "дозволене зменшення висоти сторінки")
("allowed page height reduction:" "допустиме зменшення висоти сторінки:")
("allowed positions" "дозволені позиції")
("allowed positions of floating object" "дозволені позиції плаваючого обʼєкта")
("allowed reduction" "дозволене зменшення")
("allow for macro definitions in preamble" "дозволити визначення макросів у преамбулі")
("all saved passphrases will be lost forever" "всі збережені парольні фрази будуть втрачені назавжди")
("all saved passphrases will be lost forever!" "всі збережені фрази-паролі будуть втрачені назавжди!")
("all users" "всі користувачі")
("alpha release" "альфа-версія")
("alpha transparency" "альфа-прозорість")
("also on paper" "також на папері")
("alter" "змінити")
("alternate" "альтернативні")
("alternate except here" "альтернативні, крім тут")
("alternate from here on" "чергуються звідси далі")
("alternate only here" "чергувати лише тут")
("alternate until here" "чергувати, поки тут")
("alternative colors" "альтернативні кольори")
("alternative specification" "альтернативна специфікація")
("alt key" "клавіша Alt")
("always" "завжди")
("american" "американська")
("a modifier" "модифікатор")
("A modifier" "модифікатор A")
("amplified" "посилено")
("amsmath" "amsmath")
("a.M.S. subject class" "предметний клас A.M.S.")
(" and " " і ")
("and" "і")
("and perform casual settings from the \"Encryption\" tab." "та виконайте необхідні налаштування на вкладці \"Шифрування\".")
("and perform casual settings from the \"Encryption\" tab" "та виконувати випадкові налаштування з вкладки «Шифрування»")
("angular" "кутовий")
("an icon tab bar" "Панель вкладок з іконками")
("animate" "анімувати")
("animated" "анімовані")
("animate folding" "анімувати складання")
("animate unfolding" "анімувати розгортання")
("animation" "анімація")
("animation toolbar" "панель інструментів для анімації")
("annotate" "анотувати")
("answer" "відповідь")
("answer field" "поле відповіді")
("answers only" "Тільки відповіді")
("answer to question" "відповідь на питання")
("any" "будь-який")
("appear" "зʼявитися")
("appendix" "додаток")
("appends @val to the list of values of preference @which" "Додає @val до списку значень налаштування @which")
("apply" "застосувати")
("apply macro" "застосувати макрос")
("apply macro once" "застосувати макрос один раз")
("approximate" "приблизний")
("april" "квітень")
("arab" "арабська")
("arc" "дуга")
("arc cosine" "арккосинус")
("archaic" "архаїчний")
("architecture" "архітектура")
("arch series" "аркова серія")
("arc sine" "арксинус")
("arc tangent" "арктангенс")
("are we inside the line of a textual document?" "чи знаходимось ми всередині рядка текстового документа?")
("are we inside the main document flow?" "Чи знаходимося ми всередині основного потоку документа?")
("are you sure you want to delete collected public keys" "Ви впевнені, що хочете видалити зібрані публічні ключі")
("are you sure you want to delete collected public keys?" "ви впевнені, що хочете видалити зібрані публічні ключі?")
("are you sure you want to delete selected public keys" "Ви впевнені, що хочете видалити вибрані публічні ключі")
("are you sure you want to delete selected public keys?" "ви впевнені, що хочете видалити обрані публічні ключі?")
("are you sure you want to delete selected secret keys" "Ви впевнені, що хочете видалити вибрані секретні ключі")
("are you sure you want to delete selected secret keys?" "ви впевнені, що хочете видалити обрані секретні ключі?")
("are you sure you want to destroy the wallet" "Ви впевнені, що хочете знищити гаманець")
("are you sure you want to destroy the wallet?" "ви впевнені, що хочете знищити гаманець?")
("argument" "аргумент")
("arithmetic" "арифметика")
("armenian" "вірменська")
("arrow" "стрілка")
("arrows" "стрілки")
("art frame" "художня рамка")
("article" "стаття")
("arxiv category" "категорія arXiv")
("a series" "серія")
("as on paper" "як на папері")
("aspect" "аспект")
("assign" "призначити")
("assign @ref with @t." "Присвоїти @ref значення @t.")
("as visual grid" "як візуальна сітка")
("a tab bar" "Панель вкладок")
("at fraction bar height" "на висоті риски дробу")
("attach" "долучити")
("attach buffer to which project" "долучити буфер до якого проекту")
("attach master" "прикріпити майстра")
("at the baseline" "на рівні основної лінії")
("at the bottom" "знизу")
("at the left" "ліворуч")
("at the middle" "у центрі")
("at the right" "поруч")
("at the top" "зверху")
("august" "серпень")
("author" "автор")
("author:" "автор:")
("authorize" "авторизувати")
("auto" "авто")
("auto" "автоматично")
("automatic" "автоматичний")
("automatically close brackets" "автоматично закрити дужки")
("automatically generated content" "автоматично генерований контент")
("automatically import bibliographies when opening files" "автоматично імпортувати бібліографії при відкритті файлів")
("automatically remember all passphrases in the wallet" "автоматично запамʼятовувати всі парольні фрази в гаманці")
("automatically remember all passphrases in the wallet?" "автоматично запамʼятовувати всі фрази-паролі в гаманці?")
("automatically save" "автоматично зберегти")
("automatically save:" "автоматично зберігати:")
("automatic brackets" "автоматичні дужки")
("automatic brackets:" "автоматичні дужки:")
("automatic content generation" "автоматичне створення вмісту")
("automatic determination of cell height." "Автоматичне визначення висоти комірки.")
("automatic determination of cell width." "Автоматичне визначення ширини комірки.")
("automatic determination of table height." "Автоматичне визначення висоти таблиці.")
("automatic determination of table width." "Автоматичне визначення ширини таблиці.")
("automatic program brackets" "автоматичні дужки програми")
("automatic quotes" "автоматичні лапки")
("automatic quotes:" "автоматичні лапки:")
("autosave" "автозбереження")
("auto-save file" "файл автоматичного збереження")
("axiom" "аксіома")
("axis" "вісь")
("back" "назад")
("background" "тло")
("background:" "фон:")
("background color" "колір тла")
("background color:" "колір фону:")
("background evaluations" "фонові оцінки")
("backtrace errors" "відстеження помилок")
("backward replace" "замінити назад")
("backward search" "шукати назад")
("bad data format" "поганий формат даних")
("balloon" "балон")
("bar" "смужка")
("bard" "bard")
("base" "база")
("base family:" "базова сімʼя:")
("base level" "базовий рівень")
("baseline" "базова лінія")
("base style:" "базовий стиль:")
("bashkirian" "башкирська")
("basic" "базовий")
("basic communication using pipes" "базове спілкування за допомогою каналів")
("basic data types" "базові типи даних")
("basic types" "базові типи")
("beamer" "проектор")
("beamer formats" "формат beamer")
("beamer theme" "тема beamer")
("become a TeXmacs developer" "як стати розробником TeXmacs")
("before" "перед")
("begin" "початок")
("begin primitive for content generation" "Почати примітив для генерації вмісту")
("below" "знизу")
("bench" "лавка")
("bend bottom" "згин вниз")
("bend corner" "згин кута")
("bend diagonal" "згин по діагоналі")
("bend in" "згин всередину")
("bend out" "згин назовні")
("beta release" "бета версія")
("be useful" "будьте корисними")
("bezier" "Безьє")
("bibliography" "література")
("bibliography file" "файл літератури")
("bibliography style" "стиль літератури")
("bibTeX" "bibTeX")
("bibTeX command" "команда BibTeX")
("bibTeX command:" "команда bibTeX:")
("bibTeX -> TeXmacs" "bibTeX -> TeXmacs")
("bidirectional" "двонаправлений")
("big" "великий")
("big environment box" "велика середовищна коробка")
("big figure" "великий малюнок")
("big focus" "великий фокус")
("big operator" "великий оператор")
("big skip" "великий пробіл")
("big table" "велика таблиця")
("binary operation" "бінарна операція")
("binary operator" "бінарний оператор")
("binary relation" "двійкове відношення")
("bitmap resolution (dpi):" "роздільна здатність бітового зображення (dpi):")
("bitmap resolution (dpi)" "роздільна здатність растрового зображення (dpi)")
("black" "чорний")
("blackboard" "шкільна дошка")
("blackboard bold:" "жирний дошка:")
("blackboard bold" "рукописний жирний")
("blackboard embold" "чорна дошка")
("blackboard math" "рукописний математичний")
("black floral I" "чорний квітковий I")
("black floral II" "чорний квітковий II")
("blackletter" "blackletter")
("blank column" "порожній стовпець")
("blank row" "порожній рядок")
("block" "блок")
("block content" "вміст блоку")
("block content:" "вміст блоку:")
("block of code" "блок коду")
("blue" "синій")
("bluish" "голубувате")
("blur" "розмиття")
("blur:" "розмиття:")
("body" "тіло")
("bold" "жирний")
("bold:" "жирний:")
("book" "книга")
("border" "межа")
("boring white" "тупо біле")
("both" "обої")
("both versions" "обидві версії")
("bottom" "низ")
("bottom:" "низ:")
("bottom baseline" "нижня базова лінія")
("bottom border" "нижня межа")
("bottom cell border" "нижня межа комірки")
("bottom cell padding" "нижня відступ комірки")
("bottom margin" "нижнє поле")
("bottom padding" "нижній заповнювач")
("bottom table border" "нижня межа таблиці")
("bottom table padding" "нижня відступ таблиці")
("bottom tools" "нижні інструменти")
("box" "коробка")
("branch" "гілка")
("break" "розрив")
("breaking" "розбиваю")
("breve" "breve")
("british" "британська")
("broken white" "пошкоджений білий")
("brown" "коричневий")
("browse" "перегляд")
("browse back" "переглянути назад")
("browse forward" "переглянути вперед")
("browse modules documentation" "переглянути документацію модулів")
("browser" "переглядач")
("browse symbols documentation" "Переглянути документацію про символи")
("browse web" "перегляд Тенет")
("b series" "b серія")
("buffer" "буфер")
("buffer management" "управління буфером")
("buffer management:" "управління буфером:")
("buffer must be on disk" "буфер повинен бути на диску")
("buffer must have a name" "буфер повинен мати назву")
("build-all" "зібрати все")
("build buffer" "буфер збірки")
("build buffer in" "створити буфер в")
("build directory" "каталог збірки")
("build directory in" "створити каталог в")
("build link list for identifiers in @ids" "Побудувати список посилань для ідентифікаторів в @ids")
("build link pages" "створити посилання")
("build page with environments of type @env in current buffer." "Побудувати сторінку з оточеннями типу @env у поточному буфері.")
("build possibly filtered link list for @t and its ancestors." "Побудувати, можливо, відфільтрований список посилань для @t та його предків.")
("build possibly filtered link list for @t and its descendants." "Побудувати, можливо, відфільтрований список посилань для @t та його нащадків.")
("build possibly filtered link list for the tree @t." "Побудувати, можливо, відфільтрований список посилань для дерева @t.")
("bulgarian" "болгарська")
("bullet" "точка")
("bullets" "точки")
("bump" "випуклість")
("busy" "зайнято")
(" by: " " на: ")
("by" "по")
("bytes free" "байт вільно")
("bytes used" "байт використано")
("by typing" "вводячи")
("cache expanded menu @r." "Кешувати розгорнуте меню @r.")
("calculus" "розрахунок")
("call @fun with interactively specified arguments @args" "Викликати @fun з інтерактивно вказаними аргументами @args")
("calligraphic:" "каліграфічний:")
("calligraphic" "рукописний")
("cancel" "скасувати")
("Cancel" "Cкасувати")
("cancelled" "скасовано")
("cannot download directory to file" "Неможливо завантажити каталог у файл")
("cannot rename across different servers" "не можна перейменувати на різних серверах")
("cannot upload directory to file" "Неможливо завантажити каталог у файл")
("caps-lock key" "клавіша caps-lock")
("cartesian" "декартовий")
("carved wood" "різьблене дерево")
("case" "випадок")
("case:" "регістр:")
("case-insensitive search" "пошук без розрізнення регістру")
("categories" "категорії")
("category" "категорія")
("category:" "категорія:")
("cc" "cc")
("cell" "комірка")
("cell background color" "колір тла комірки")
("cell border" "межі комірки")
("cell height" "висота комірки")
("cell operation mode" "режим операції над коміркою")
("cell properties" "властивості комірок")
("cells" "комірки")
("cell width" "ширина комірки")
("center" "центр")
("center:" "центр:")
("centered" "центрований")
("centered block" "центрований блок")
("centered tabular" "центрована таблиця")
("center text" "центрувати текст")
("change border of cell" "змінити межу комірки")
("change cell operation mode" "змінити режим операції над коміркою")
("change default unit" "змінити стандартну одиницю")
("change global locus rendering property @var to @val." "Змінити властивість глобального відображення локусу @var на @val.")
("change log" "журнал змін")
("change passphrase" "змінити парольну фразу")
("changes" "зміни")
("change step-size" "змінити розмір кроку")
("change tags" "змінити теги")
("change the border of the table" "змінити межу таблиці")
("change the style of a widget" "Змінити стиль віджета")
("change the style of mathematical formulas" "змінити стиль математичних формул")
("change the TeXmacs preferences" "змінити налаштування TeXmacs")
("chapter" "глава")
("character contraction" "стиснення символів")
("character contraction:" "стиснення символів:")
("character encoding" "кодування символів")
("character encoding:" "кодування символів:")
("character expansion" "розширення символів")
("character expansion:" "розширення символів:")
("check" "перевірка")
("checkable field" "поле, яке можна перевірити")
("check exported Pdf files for correctness" "перевірити експортовані Pdf файли на правильність")
("check for automatic updates:" "перевірка автоматичних оновлень:")
("check for updates" "перевірити наявність оновлень")
("check text for spelling errors" "перевірити правопис тексту")
("check whether a given ptree @pt contains all items in the list @l" "Перевірити, чи містить задане ptree @pt всі елементи у списку @l")
("check whether @t is a table inside a calc-table" "Перевіряє, чи є @t таблицею всередині calc-table")
("chinese" "китайська")
("choice" "вибір")
("choice:" "вибір:")
("choices:" "варіанти:")
("cipher algorithm for passphrase encryption" "алгоритм шифрування парольної фрази")
("cipher algorithm for passphrase encryption:" "алгоритм шифрування паролю для фрази-пароля:")
("circle" "коло")
("citation" "цитування")
("cite" "цитата")
("cite a paper or other work on TeXmacs" "Цитувати статтю або іншу роботу з TeXmacs")
("cite TeXmacs" "Цитувати TeXmacs")
("cJK" "cJK")
("cJK spacing:" "розмір пробілів для cJK:")
("cJK spacing" "cJK інтервал")
("class" "клас")
("classification" "класифікація")
("clean slate" "чистий аркуш")
("clear" "очистити")
("clear all fields" "очистити всі поля")
("clear font cache" "очистити кеш шрифтів")
("clear font cache under TEXMACS_HOME_PATH." "Очистити кеш шрифтів у TEXMACS_HOME_PATH.")
("clear local information" "очистити локальну інформацію")
("clear menu" "очистити меню")
("clear selection" "зняти виділення")
("clear undo history" "очистити історію скасування")
("click Ok button twice to discard this warning" "натисніть кнопку ОК двічі, щоб відхилити це попередження")
("click Ok button twice to discard this warning." "натисніть кнопку \"ОК\" двічі, щоб проігнорувати це попередження.")
("clip" "обрізати")
("clipboard image format" "формат зображення буфера обміну")
("clipboard image format:" "формат зображення в буфері обміну:")
("clipped" "обрізаний")
("clipped and magnified" "обрізаний і збільшений")
("clipped and resized" "обрізаний і змінений розмір")
("clone" "клонувати")
("clone window" "клонувати вікно")
("close" "закрити")
("close animation tool" "інструмент закриття анімації")
("close buffer" "закрити буфер")
("closed bezier" "закритий безьє")
("closed curve" "закрита крива")
("close document" "закритий документ")
("closed smooth" "закритий гладкий")
("closed spline" "закритий сплайн")
("close program" "Закрити програму")
("close replace tool" "інструмент закрити заміну")
("close search tool" "Закрити інструмент пошуку")
("close session" "закрити сесію")
("close spell tool" "інструмент закриття орфографії")
("close TeXmacs" "закрити TeXmacs")
("close translations to rebuild" "закритих перекладів для відновлення")
("close window" "закрити вікно")
("closing" "закриваю")
("closing style" "стиль закриття")
("closing style:" "стиль закриття:")
("cluster by affiliation" "кластер за приналежністю")
("code" "код")
("collect all explain tags available in the documentation." "Зібрати всі теги пояснень, доступні в документації.")
("collected keys" "зібраних ключів")
("collect garbage" "збирай сміття")
("collect public keys from buffer" "Зібрати публічні ключі з буфера")
("color" "колір")
("color:" "колір:")
("color of the axes" "колір осей")
("color of the subunits" "колір підрозділів")
("color of the units" "колір одиниць")
("colors" "кольори")
("column" "стовпець")
("column contains glued items" "стовпець містить склеєні елементи")
("columns:" "стовпці:")
("columns" "стовпців")
("column separation:" "відстань між стовпцями:")
("column separation" "розділення стовпців")
("column to the left" "стовпець зліва")
("column to the right" "стовпець праворуч")
("columnwidth:" "ширина колонки:")
("command" "команда")
("comment:" "коментар:")
("commit file" "файл фіксації")
("common" "звичайних")
("common formats" "загальних форматів")
("commutative diagram" "комутативна схема")
("compact" "компактний")
("compactification:" "компактизація:")
("compactification" "ущільнення")
("compactify" "ущільнити")
("compatibility with other formats" "сумісність з іншими форматами")
("compile article" "скомпілювати статтю")
("compile book" "скомпілювати книгу")
("compile buffer" "скомпілювати буфер")
("compile project" "скомпілювати проект")
("complete bibliographic reference" "повна бібліографічна довідка")
("completes missing cells on rows of @t with empty strings" "Доповнює відсутні комірки на рядках @t порожніми рядками")
("completion" "завершення")
("completions for @s in the bibtex file @u as a list" "Завершення для @s у файлі bibtex @u у вигляді списку")
("completions for @t in the bibtex file @u for custom-complete" "Завершення для @t у файлі bibtex @u для custom-complete")
("complex" "комплексний")
("complex actions" "складних дій")
("complex actions:" "складні дії:")
("compose" "скласти")
("compound" "зʼєднання")
("compress" "стиснути")
("compressed" "стиснутий")
("compress into toolbar" "стиснути у панель інструментів")
("compute preamble for @text" "Обчислює преамбулу для @text")
("conceal" "приховувати")
("concrete" "конкретний")
("condensed" "стиснутий")
("condition" "умова")
("cond primitive for content generation" "Умова примітиву для генерації вмісту")
("configuration" "конфігурація")
("configure look and feel" "Налаштувати зовнішній вигляд")
("confirm database entry" "підтвердити введення бази даних")
("confirm entry" "підтвердити запис")
("confirm selected database entries" "підтвердити вибрані записи бази даних")
("confirm selected entries" "підтвердити вибрані записи")
("conservative conversion options" "консервативні варіанти перетворення")
("consoles" "консолі")
("constellation" "сузірʼя")
("constructor of horizontal concatenations with corrections." "Конструктор горизонтального зʼєднання з корекцією.")
("contact" "контакт")
("content" "вміст")
("content tag" "тег вмісту")
("context aids" "контекстні посібники")
("context dependent icons" "іконки, що залежать від контексту")
("contextual hints" "контекстуальні підказки")
("continuation of" "продовження")
("continue" "продовжити")
("continued fraction" "продовження дробу")
("contour" "контур")
("contract logarithms" "логарифми контрактів")
("contribute" "сприяти")
("control flow" "контрольний потік")
("control the evaluation of expressions" "контроль оцінки виразів")
("convention" "угода")
("convert" "конвертувати")
("convert an TeXmacs XML stree @s into TeXmacs." "Перетворює дерево TeXmacs XML @s в TeXmacs.")
("convert a parsed BibTeX stree @t into a TeXmacs stree." "Перетворити розібране дерево BibTeX @t в дерево TeXmacs.")
("convert a parsed Gallina stree @t into a TeXmacs stree." "Перетворити розібраний дерево Gallina @t в дерево TeXmacs.")
("convert a parsed HTML stree @t into a TeXmacs stree." "Перетворити розібране дерево HTML @t в дерево TeXmacs.")
("converters" "перетворювачі")
("converters to other data formats" "конвертери до інших форматів даних")
("convertible" "конверсійний")
("convert mathematical expression @x into TeXmacs tree." "Перетворити математичний вираз @x у дерево TeXmacs.")
("convert mathematical input to a string" "Перетворити математичний ввід у рядок")
("convert the MathML @s into a document fragment." "Перетворює MathML @s в фрагмент документа.")
("copy" "скопіювати")
("copying" "копіювання")
("copyright" "авторські права")
("copy text" "копіювати текст")
("copy to" "копіювати до")
("cork charset with TeX catcode definition in preamble" "пробкова набір з визначенням коду TeX у преамбулі")
("corollary" "наслідок")
("correct: " "виправити: ")
("correct" "правильно")
("correct all" "виправити все")
("correct formula" "правильна формула")
("correction" "виправлення")
("correct manually" "виправити вручну")
("correct mathematical formulas" "правильні математичні формули")
("correct selected formula or all formulas in document" "Виправити вибрану формулу або всі формули в документі")
("correct text" "виправити текст")
("correct the tree @(tree-ref t . l) and its ancestors" "Виправити дерево @(tree-ref t . l) та його предків")
("correct the tree @(tree-ref t . l) and its descendants" "Виправити дерево @(tree-ref t . l) та його нащадків")
("cosine" "косинус")
("count characters" "кількість символів")
("count lines" "кількість рядків")
("count words" "рахувати слова")
("create a new document" "створити новий документ")
("create a new GnuGP identity" "Створити нову ідентичність GnuPG")
("create a preamble for the current document" "Створити преамбулу для поточного документа")
("create a tmlength object from its string representation." "Створити обʼєкт tmlength з його рядкового представлення.")
("create a tmlength object given its value and unit components." "Створити обʼєкт tmlength з використанням його значення та компонентів одиниці.")
("create a unique file or locus identifier" "Створити унікальний ідентифікатор файлу або локусу")
("create context macro" "Створити контекстний макрос")
("create link" "створити посилання")
("create preamble" "створити преамбулу")
("create remote directory" "створити віддалений каталог")
("create remote file" "створити віддалений файл")
("creates a copy of @buf in @u and return @u." "Створює копію @buf в @u і повертає @u.")
("create shortcut..." "створити скорочення")
("create subprogram" "створити підпрограму")
("create subsession" "створити підсесію")
("create table macro" "створити макрос таблиці")
("create web site" "створити веб-сайт")
("creating new account" "створення нового облікового запису")
("creating technical pictures" "створення технічних зображень")
("croatian" "хорватська")
("crop" "обрізати")
("crop marks" "маркери обрізки")
("crop marks:" "позначки обрізки:")
("cross" "хрест")
("crossed boxes" "перекреслені квадрати")
("crossed circles" "перекреслені кола")
("cSS stylesheet:" "cSS таблиця стилів:")
("current user version" "поточна версія користувача")
("current version" "поточна версія")
("cursor" "курсор")
("cursors" "курсори")
("curve" "крива")
("curve intersections" "перетини кривих")
("curve points" "точки кривих")
("customizations" "налаштування")
("customize macro..." "змінити макрос...")
("customizing and extending the user interface" "налаштування та розширення інтерфейсу користувача")
("customizing TeXmacs" "налаштування TeXmacs")
("customizing the TeXmacs styles" "налаштування стилів TeXmacs")
("custom tab" "змінна табуляція")
("custum tab" "змінна табуляція")
("cut" "вирізати")
("cut text" "вирізати текст")
("cut to" "вирізати до")
("cypriot" "кіпрська")
("cyrillic" "кириличний")
("cyrillic input method" "метод введення кирилиці")
("cyrillic input method:" "метод введення кирилиці:")
("cyrillic italic right" "кириличний курсив вправо")
("czech" "чеська")
("dancers" "танцюристи")
("danish" "данська")
("dark grey" "темно-сірий")
("dark vador" "дарк вейдор")
("dash" "риска")
("dashes" "риски")
("data" "дані")
("database entry" "запис бази даних")
("database tool" "інструмент бази даних")
("database toolbar" "панель інструментів бази даних")
("data conversion" "перетворення даних")
("data format" "формат даних")
("date" "дата")
("deactivate" "деактивувати")
("deactivate once" "деактивувати один раз")
("deactivate table" "деактивувати таблицю")
("dead" "мертві")
("debug" "налагодження")
("debugging console" "консоль налагодження")
("debugging tool" "інструмент налагодження")
("december" "грудень")
("decimal comma" "десяткова кома")
("decimal dot" "десяткова крапка")
("decomposed" "розкладено")
("decompose mathematical string @s into list of tokens." "Розкласти математичний рядок @s на список токенів.")
("decorate atoms" "декорування атомів")
("decorated" "прикрашений")
("decorated wood" "прикрашена деревина")
("decrease size" "зменшити розмір")
("decrypt" "розшифрувати")
("default" "за замовчуванням")
("default padding" "заповнювач за замовчуванням")
("default semantics for mathematical formulas" "типова семантика для математичних формул")
("default semantics for mathematical symbols" "типова семантика для математичних символів")
("default size" "типовий розмір")
("default syntax for mathematical formulas" "типовий синтаксис для математичних формул")
("define a smart table @t with entries @l" "Визначити розумну таблицю @t з елементами @l")
("define the formal language @lan" "Визначити формальну мову @lan")
("definition" "визначення")
("degrade" "погіршити")
("degraded" "деградовано")
("delayed when primitive for content generation" "Відкладено, коли примітив для генерації вмісту")
("delete" "видалити")
("delete binding for @key in the wallet" "Видалити звʼязок для @key з гаманця")
("delete column" "видалити колонку")
("deleted" "видалено")
("delete documentation cache" "видалити кеш документації")
("delete entries" "видалити записи")
("delete GnuPG public key of fingerprint @fingerprint" "Видалити публічний ключ GnuPG з відбитком @fingerprint")
("delete GnuPG secret and public keys of fingerprint @fingerprint" "Видалити секретні та публічні ключі GnuPG з відбитком @fingerprint")
("delete link" "видалити посилання")
("delete row" "видалити рядок")
("delete the documentation cache" "Видалити кеш документації")
("denominator" "знаменник")
("deprecated old tree correction routine" "Застаріла процедура корекції старого дерева")
("describe" "описати")
("describe tag" "описати тег")
("description" "опис")
("destination" "призначення")
("destination directory:" "директорія призначення:")
("destroy" "знищити")
("destroy wallet" "Знищити гаманець")
("detach" "відʼєднати")
("detach master" "відʼєднати майстра")
("detailed" "детально")
("detailed menus" "докладні меню")
("details in menus" "деталі в меню")
("details in menus:" "деталі в меню:")
("determinant" "детермінант")
("determine all dependencies of packages @ps" "Визначає всі залежності пакетів @ps")
("determine margins from text width" "визначити поля з ширини тексту")
("devangari" "деванагарі")
("developer" "розробник")
("developers guide" "керівництво розробника")
("developer tool" "інструмент розробника")
("device" "пристрій")
("device:" "пристрій:")
("diamond" "діамант")
("did enter all necessary information for constructing a link?" "Ввели всю необхідну інформацію для створення посилання?")
("differentiate" "відрізняти")
("dilate" "розширити")
("direction of progression" "напрямок прогресування")
("direction of translation" "напрямок перекладу")
("directory" "каталог")
("disable" "вимкнути")
("disable coloring on paper" "вимкнути забарвлення на папері")
("disable encryption" "вимкнути шифрування")
("disable first indentation" "заборонити перший відступ")
("disable first indentation after" "заборонити перший відступ після")
("disable first indentation before" "заборонити перший відступ перед")
("disable indentation" "заборонити відступ")
("disable indentation after" "заборонити відступ після")
("disable indentation before" "заборонити відступ перед")
("disable last indentation" "заборонити останній відступ")
("disable last indentation after" "заборонити останній відступ після")
("disable last indentation before" "заборонити останній відступ перед")
("disallow" "заборонити")
("disallow any link types from being followed." "Заборонити слідування будь-яким типам посилань.")
("disappear" "зникнути")
("disk" "диск")
("display command @cmd with its standard outputs @out and @err" "Відобразити команду @cmd зі стандартними виводами @out та @err")
("displayed formula" "відображена формула")
("display style" "стиль відображення")
("display the help window for @key in the @where documentation" "Відображає вікно довідки для @key в документації @where")
("dissociate joined cells" "розʼєднати обʼєднані комірки")
("distill encapsulated Pdf files" "перетворити вкладені Pdf файли")
("distort" "спотворити")
("distorted" "спотворено")
("distribute unused space" "розподілити вільний проміжок")
("div" "поділити")
("division" "ділення")
("document" "документ")
("documentation" "документація")
("document font selector" "вибір шрифту документа")
("document format" "формат документу")
("document language" "мова документа")
("document page format" "формат сторінки документа")
("document paragraph format" "формат абзацу документа")
("documents are trees" "документи є деревами")
("document style" "стиль документа")
("document styles" "стилі документів")
("document updates run:" "оновлення документа виконуються:")
("document updates run" "оновлення документа запущено")
("does @s contain only whitespace?" "чи містить @s лише пробіли?")
("does @s only contain spaces?" "чи містить @s лише пробіли?")
("does @t contain an active link?" "Чи містить @t активне посилання?")
("does the cell contain block content?" "Чи містить комірка блоковий вміст?")
("does the current buffer contain a preamble?" "Чи містить поточний буфер преамбулу?")
("does the document tree @t contain a preamble?" "Чи містить дерево документа @t преамбулу?")
("does there exist a next position in history?" "Чи існує наступна позиція в історії?")
("does there exist a previous position in history?" "Чи існує попередня позиція в історії?")
("done" "Готово")
("do not remap" "не переназначати")
("dot" "крапка")
("dots" "крапки")
("double stroke:" "подвійна лінія:")
("double stroke" "подвійний")
("double the zoom factor for TeXmacs documents:" "подвоїти коефіцієнт масштабування для документів TeXmacs:")
("down" "вниз")
("down:" "вниз:")
("download" "завантажити")
("downwards" "вниз")
("dpi" "точок на дюйм")
("dragging" "перетягування")
("draw image" "намалювати зображення")
("draw over" "намалювати поверх")
("draw over selection" "намалювати поверх вибору")
("drop" "випадати")
("due to" "через")
("duplicate" "дублювати")
("dutch" "голландська")
("dynamic" "динамічний")
("dynamic libraries" "динамічні бібліотеки")
("edit" "редагувати")
("edit animation" "редагувати анімацію")
("edit groups of objects" "редагувати групи обʼєктів")
("editing tools" "утиліти редагування")
("edit keyboard shortcuts" "Редагувати клавіатурні скорочення")
("edit list of recipients" "Редагувати список отримувачів")
("edit macro" "редагувати макрос")
("edit macros" "редагувати макроси")
("edit preamble" "редагувати преамбулу")
("edit source" "редагувати джерело")
("edit source tree" "редагувати дерево джерела")
("edit style" "редагувати стиль")
("edit translations file" "редагувати файл перекладів")
("education" "освіта")
("effect pen" "ручка з ефектом")
("eigenvalues" "власні значення")
("eighth" "восьмий")
("eighth:" "восьмий:")
("email:" "електронна пошта:")
("email" "ел. пошта")
("embold" "жирний")
("embold:" "жирність:")
("emboss" "тиснення")
("emphasize" "виділення")
("emphasize text" "виділити текст")
("empty box" "порожній бокс")
("enable first indentation" "дозволити перший відступ")
("enable first indentation after" "дозволити перший відступ після")
("enable first indentation before" "дозволити перший відступ перед")
("enable indentation" "дозволити відступ")
("enable indentation after" "дозволити відступ після")
("enable indentation before" "дозволити відступ перед")
("enable last indentation" "дозволити останній відступ")
("enable last indentation after" "дозволити останній відступ після")
("enable last indentation before" "дозволити останній відступ перед")
("enable page breaking" "увімкнути розрив сторінки")
("encl" "encl")
("encoding" "кодування")
("encrypt" "шифрувати")
("encrypt all passphrase decrypted regions" "Зашифрувати всі розшифровані області паролем")
("encrypt and save object @o to @url for @fingerprint" "Зашифрувати та зберегти обʼєкт @o до @url для @fingerprint")
("encrypt and save string @s to @url for @fingerprint" "Зашифрувати та зберегти рядок @s до @url для @fingerprint")
("encrypt buffer" "Зашифрувати буфер")
("encrypt current block" "Зашифрувати поточний блок")
("encrypt current inline region" "Зашифрувати поточну вбудовану область")
("encryption" "шифрування")
("encryption facilities are not currently available" "засоби шифрування наразі недоступні")
("encryption facilities are not currently available." "можливості шифрування в даний момент недоступні.")
("encryption facilities have not been enabled for TeXmacs." "засоби шифрування не активовані для TeXmacs.")
("encryption facilities have not been enabled for TeXmacs" "засоби шифрування не ввімкнено для TeXmacs")
("\"encryption\" features from the preference panel" "можливості «шифрування» з панелі налаштувань")
("\"Encryption\" features from the preference panel." "функції \"Шифрування\" з панелі налаштувань.")
("encrypt @t" "Зашифрувати @t")
("end" "кінець")
("enforce brackets to match" "забезпечити відповідність дужок")
("english" "англійська")
("engrave" "гравірувати")
("ensure that the documentation cache is built." "Переконатися, що кеш документації побудований.")
("enter a title" "введіть заголовок")
("enter data" "ввести дані")
("enter graphics" "ввести графіку")
("enter graphics mode" "увійти в режим графіки")
("enter new passphrase for encryption" "введіть нову фразу для шифрування")
("enter passphrase for decryption" "введіть фразу для розшифрування")
("enter passphrase for identity" "введіть фразу для ідентифікації")
("enter title information" "введіть інформацію про заголовок")
("entire table" "вся таблиця")
("entry up to date in database" "запис оновлено в базі даних")
("enum:" "перерахування:")
("enumerate" "пронумерований список")
("enumerate|alpha" "пронумерований|алфа")
("enumerate|Alpha" "пронумерований|Альфа")
("enumerate|Roman" "пронумерований|Римський")
("enumerate|roman" "пронумерований|римський")
("enunciation" "проголошення")
("env" "середовище")
("environment" "середовище")
("environments" "середовища")
("environment variable" "змінна середовища")
("epilogue" "епілог")
("equal" "дорівнює")
("equation" "рівняння")
("equations" "рівняння")
("equivalent for" "еквівалентно")
("erode" "еродувати")
("eRROR" "помилка")
("error" "помилка")
("error: bracket does not match" "помилка: дужка не збігається")
("error: cyclic or missing chunks detected" "помилка: виявлено циклічні або відсутні фрагменти")
("error: file not found" "помилка: файл не знайдено")
("error: ghostview does not seem to be installed on your system" "помилка: здається, ghostview не встановлено у вашій системі")
("error messages" "повідомлення про помилки")
("error: one of the alternatives should be filled out" "помилка: одну з альтернатив має бути заповнена")
("error: only one alternatives should be filled out" "помилка: має бути заповнена лише одна альтернатива")
("error output" "вивід помилки")
("error: should fill out name for referencing" "помилка: має бути заповнене імʼя для посилання")
("error: should fill out required field" "помилка: має бути заповнене обовʼязкове поле")
("error status report" "звіт про стан помилки")
("esperanto" "есперанто")
("etruscan" "етруська")
("evaluable field" "поле, що підлягає оцінці")
("evaluate" "обчислити")
("evaluate above" "оцінити вище")
("evaluate all" "оцінити все")
("evaluate below" "оцінити нижче")
("evaluate fields" "оцінити поля")
("evaluate fields in order" "оцінити поля у порядку")
("evaluate scheme expression" "обчислити вираз scheme")
("evaluate script" "оцінити сценарій")
("evaluation" "оцінка")
("evaluation switch" "перемикач оцінки")
("evaluation tag" "тег оцінки")
("even page" "рівна сторінка")
("even page footer" "нижній колонтитул парної сторінки")
("even page header" "верхній колонтитул парної сторінки")
("(Even page) Left:" "(Парна сторінка) Зліва:")
("even page left margin" "лівий відступ рівної сторінки")
("even page margin" "поля парних сторінок")
("(even pages)" "(парні сторінки)")
("even pages" "рівні сторінки")
("even page shift:" "зсув парних сторінок:")
("even page shift" "зсув рівної сторінки")
("even page text" "текст парної сторінки")
("evensidemargin:" "ліва межа парних сторінок:")
("events" "події")
("exact" "точно")
("exact horizontal" "точна горизонтальна")
("exact mode" "точний режим")
("exam" "екзамен")
("example" "приклад")
("exclusive" "виключний")
("exclusive or" "або, що виключає")
("executable" "виконуваний")
("execute" "виконати")
("execute a TeXmacs command" "виконати команду TeXmacs")
("execute one command" "Виконати одну команду")
("execute promise to define the language @lan" "Виконати обіцянку, щоб визначити мову @lan")
("execute system command" "виконати системну команду")
("execution of scripts" "виконання скриптів")
("execution of scripts:" "виконання скриптів:")
("executive" "виконавчий")
("exercise" "вправа")
("exit graphics" "вийти з графіки")
("exit graphics mode" "вийти з графічного режиму")
("exit left" "вийти зліва")
("exit right" "вийти справа")
("exit tag on the left" "вийти тег зліва")
("exit tag on the right" "вийти тег справа")
("expand" "розгорнути")
("expand all TeXmacs macros occurring in @t" "Розгортає всі макроси TeXmacs, що зустрічаються в @t")
("expand beamer slides" "розгорнути слайди beamer")
("expanded" "розгорнуто")
("expand inclusions" "розгорнути включення")
("expand links and conditional menus in menu @p." "Розгорнути посилання та умовні меню в меню @p.")
("expand logarithms" "розгорнути логарифми")
("expand TeXmacs macros with no LaTeX equivalents" "розгорнути макроси TeXmacs без еквівалентів LaTeX")
("expand trigonometric functions" "розгорнути тригонометричні функції")
("expand unrecognized macros" "розгорнути невпізнані макроси")
("expand user-defined macros" "розгорнути користувацькі макроси")
("experimental features (to be used with care)" "експериментальні функції (використовувати з обережністю)")
("explain" "пояснити")
("explained" "пояснено")
("explanatory item" "пояснювальний елемент")
("explicit keystroke" "явне натискання клавіші")
("explicit margins" "явні поля")
("exponential" "експоненційна")
("export" "експортувати")
("export as" "експортувати як")
("export bibliographies as links" "експортувати бібліографії як посилання")
("export bibliography" "експортна бібліографія")
("exported bibliographic entries" "експортовані бібліографічні записи")
("exported bibliographic references" "експортовані бібліографічні посилання")
("export entries in buffer" "експортувати записи в буфері")
("export file" "експортний файл")
("export formulas as images" "експортувати формули як зображення")
("export GnuPG public keys of fingerprint in the given list" "Експортувати публічні ключі GnuPG з відбитком з вказаного списку")
("export GnuPG secret keys of fingerprint in the given list" "Експортувати секретні ключі GnuPG з відбитком з вказаного списку")
("export mathematical formulas as images" "експорт математичних формул у вигляді зображень")
("export mathematical formulas as MathJax" "експортувати математичні формули як MathJax")
("export mathematical formulas as MathML" "експорт математичних формул як MathML")
("export selected entries" "експорт вибраних записів")
("export selection" "експорт вибраного")
("export selection as image" "експорт вибраного як зображення")
("export selections as" "експорт вибраних як")
("export sessions" "експорт сесій")
("extend" "розширити")
("extended" "розширений")
("extended:" "розширений:")
("extend or normal" "розтягнутий або звичайний")
("extend the size of a widget" "Розширити розмір віджета")
("extend vertically:" "розширити вертикально:")
("extensible left arrow" "розширювана стрілка вліво")
("extensible right arrow" "розширювана стрілка вправо")
("extern " "зовнішній")
("extern" "зовнішній")
("external" "зовнішній")
("extra" "додатковий")
("extra branch" "додаткова гілка")
("extract" "виділити")
("extract format" "точний формат")
("extract style file" "виділити файл стилю")
("extract style package" "виділити пакет стилю")
("extra interline space" "додатковий міжрядковий простір")
("extra interline space:" "додатковий міжрядковий простір:")
("extra name" "додаткове імʼя")
("factor" "фактор")
("fade" "згасає")
("fade in" "зʼявляється")
("fade out" "зникає")
("family" "сімейство")
("fast" "швидко")
("fast decrease" "швидке зменшення")
("fast environments" "швидкі середовища")
("fast increase" "швидке збільшення")
("february" "лютий")
("field reference" "посилання на поле")
("fifth" "пʼятий")
("fifth:" "пʼятий:")
("figure" "малюнок")
("file" "файл")
("file:" "файл:")
("file name" "імʼя файлу")
("file not found" "файл не знайдено")
("files" "файли")
("file saved" "файл збережено")
("fill color" "колір заливки")
("fill out" "заповнити")
("filter" "фільтр")
("find ancestor of @t which matches @what" "Знайти предка @t, який відповідає @what")
("find file" "знайти файл")
("find keyboard binding for command @com" "Знайти клавіатурне привʼязування для команди @com")
("find matching opening row for @row and bracket @br" "знайти відповідний відкриваючий рядок для @row і дужки @br")
("find modeless keyboard binding for command @cmd" "Знайти безрежимне клавіатурне привʼязування для команди @cmd")
("find next bracket @br with inverse @ibr in @s at @pos" "знайти наступну дужку @br з інверсією @ibr у @s на позиції @pos")
("find next match" "знайти наступне співпадіння")
("find previous bracket @br with inverse @ibr in @s at @pos" "знайти попередню дужку @br з інверсією @ibr у @s на позиції @pos")
("find subgroup of @group which contains @which" "Знайти підгрупу @group, яка містить @which")
("find system keyboard binding for command @com" "Знайти системне клавіатурне привʼязування для команди @com")
("find table-, column-, row- and cell- format lists of @t" "Знайти списки форматів таблиці, стовпців, рядків та комірок @t")
("find table-, column-, row- and cell- properties of @t" "Знайти властивості таблиці, стовпців, рядків та комірок @t")
("find text" "знайти текст")
("find the command associated to the keystroke @key" "Знайти команду, повʼязану з натисканням клавіші @key")
("finished collecting symbols documentation" "завершено збір документації по символах")
("finnish" "фінська")
("first" "перший")
("first:" "перший:")
("first chunk" "перший фрагмент")
("first contact" "перше знайомство")
("first difference" "перша різниця")
("first error" "перша помилка")
("first field" "перше поле")
("first indentation" "перший відступ")
("first indentation:" "перший відступ:")
("first item" "перший елемент")
("first occurrence" "перше входження")
("first page" "перша сторінка")
("first page:" "перша сторінка:")
("first similar" "перший подібний")
("first start" "перший запуск")
("fit to screen" "підігнати до екрану")
("fit to screen width" "підігнати до ширини екрану")
("five columns" "пʼять стовпців")
("fix broken citations" "виправити поламані цитати")
("fix broken references" "виправити поламані посилання")
("fix duplicate labels" "виправити дублікати міток")
("fixed" "фіксований")
("flag is off" "прапор вимкнено")
("flag is on" "прапор увімкнено")
("flat" "плоский")
("flatten" "сплющити")
("flexibility" "гнучкість")
("flexibility factor for vertical spacing" "фактор гнучкості для вертикального простору")
("float" "плаваючий")
("floating algorithm" "плаваючий алгоритм")
("floating figure" "плаваючий малюнок")
("floating object" "плаваючий обʼєкт")
("floating phantom" "плаваючий фантом")
("floating table" "плаваюча таблиця")
("focus" "фокус")
("focus balloon" "балон фокусу")
("focus dependent icons" "піктограми, що залежать від фокусу")
("focus on the tree @(tree-ref t . l)" "Сфокусуватися на дереві @(tree-ref t . l)")
("fold" "згортка")
("fold all" "згорнути все")
("fold all fields" "згорнути всі поля")
("fold at the current focus position" "Згорнути на поточній позиції фокусу")
("fold back" "згорнути назад")
("folded" "згорнутий")
("fold input field" "згорнути поле введення")
("fold using the mouse" "Згорнути за допомогою миші")
("follow external links" "перейти за зовнішніми посиланнями")
("follow inverse links" "перейти за зворотніми посиланнями")
("follow one of the links for identifiers in @ids." "Перейти за одним з посилань для ідентифікаторів у @ids.")
("follow one of the links in the current locus." "Перейти за одним з посилань у поточному локусі.")
("follow one of the links in the navigation list @nl." "Перейти за одним з посилань у списку навігації @nl.")
("follow the first link with given @type in @the-navigation-list." "Перейти за першим посиланням з даним @type у @the-navigation-list.")
("font" "шрифт")
("font base size" "базовий розмір шрифту")
("font customization" "налаштування шрифту")
("font dpi" "роздільність шрифту")
("font effects" "шрифтові ефекти")
("font family" "сімейство шрифтів")
("font name" "імʼя шрифту")
("fonts" "шрифти")
("font selector" "вибір шрифту")
("font series" "серія шрифтів")
("font shape" "фігура шрифту")
("font size" "розмір шрифту")
("font type" "тип шрифту")
("font variant" "варіант шрифту")
("footer" "підвал")
("footnote" "виноска")
("footskip:" "відступ нижнього колонтитулу:")
("for" "для")
("force reloading of translations" "примусове перезавантаження перекладів")
("for each" "для кожного")
("foreground" "колір тексту")
("foreground:" "передній план:")
("foreign" "іноземний")
("format" "формат")
("formats a module in list format (some module) as some.module" "Форматує модуль у форматі списку (some module) як some.module")
("formatted and structured output" "відформатований та структурований вихід")
("formatted date" "форматована дата")
("formatting" "форматування")
("formula" "формула")
("formula style" "стиль формули")
("for primitive for content generation" "Для примітиву для генерації вмісту")
("forward" "вперед")
("forward replace" "заміняти вперед")
("forward search" "шукати вперед")
("four columns" "чотири стовпці")
("four dots" "чотири крапки")
("fourth" "четвертий")
("fourth:" "четвертий:")
("fraction" "дріб")
("fraktur" "фрактури")
("fraktur:" "фрактурний:")
("framed" "обрамлено")
("framed theorems" "теореми у рамці")
("french" "французька")
("from" "від")
("from center" "від центру")
("front matter" "передня справа")
("full" "повний")
("full author list" "повний список авторів")
("full manuals" "повні керівництва")
("full name:" "повне імʼя:")
("full screen mode" "повноекранний режим")
("function" "функція")
("functional" "функціональних")
("fundamental tmlength deconstructor." "Основний розбірник tmlength.")
("further customization" "подальші налаштування")
("future changes" "майбутні зміни")
("gap" "пробіл")
("garbage collection" "вивезення сміття")
("gaussian" "гауссів")
("gcd" "НСД")
("general" "загальний")
("general architecture of TeXmacs" "загальна архітектура TeXmacs")
("general negation" "загальне заперечення")
("general note" "загальна примітка")
("generate a content builder from a scheme program @w" "Створити генератор вмісту з програми scheme @w")
("generated field" "генероване поле")
("generated LaTeX document contains no errors" "згенерований документ LaTeX не містить помилок")
("generate GnuPG key" "Створити ключ GnuPG")
("generates graphics format of the current selection" "Генерує графічний формат поточного виділення")
("generating font file" "генерую файл з шрифтом")
("generic" "типовий")
("geometry" "геометрія")
("georgian" "грузинська")
("german" "німецька")
("get all link types occurring in the current locus." "Отримати всі типи посилань, які зустрічаються в поточному місці.")
("get arity" "отримати арність")
("get default key fingerprint" "Отримати відбиток за замовчуванням ключа")
("get indentation arity of keyword @s" "отримати кількість відступів для ключового слова @s")
("get innermost node type among possibilities in @l." "Отримати найвнутрішніший тип вузла серед можливостей у @l.")
("get label" "отримати мітку")
("get list with remote versions" "отримати список із віддаленими версіями")
("get preference @which" "Отримати налаштування @which")
("get rightmost path until where @x can be parsed in @lan" "Отримати найправіший шлях до того, де @x може бути розібраний в @lan")
("get semantic selections englobing @in at @pos" "Отримати семантичні вибори, що охоплюють @in в @pos")
("get the entire program tree" "отримати повне дерево програми")
("get the entry @key in the table @t" "Отримати елемент @key в таблиці @t")
("get the horizontal position on the current line" "отримати горизонтальну позицію на поточному рядку")
("get the indentation of @s" "отримати відступ @s")
("get the indentation of the current line" "отримати відступ поточного рядка")
("get the list of all document parts of the current buffer" "Отримати список всіх частин документа поточного буфера")
("get the mode for document part selections" "Отримати режим вибору частини документа")
("get the position of the tree @t." "Отримати позицію дерева @t.")
("get the string at a given @row" "отримати рядок за заданим @row")
("get the unit part of @tmlen." "Отримати частину одиниці @tmlen.")
("get the url for the given Doxygen tag." "Отримати URL для заданого тега Doxygen.")
("get the value part of @tmlen." "Отримати частину значення @tmlen.")
("get the vertical position on the current line" "отримати вертикальну позицію на поточному рядку")
("getting started" "уведення")
("get value for @key from the wallet" "Отримати значення для @key з гаманця")
("glossary" "словник")
("glossary entry" "словниковий пункт")
("glue" "клей")
("glue decorations" "клейові прикраси")
("glyphs" "гліфи")
("glyphs:" "гліфи:")
("gnaw" "погризти")
("gnawed" "погризене")
("GNU" "GNU")
("gnuPG cipher algorithm for passphrase encryption" "Алгоритм шифрування GnuPG для зашифрування паролем")
("gnuPG command" "команда gnuPG")
("gnuPG command:" "команда gnuPG:")
("gnuPG decrypt armored string @data with passphrase @passphrase" "Розшифрувати зашифрований рядок @data GnuPG з паролем @passphrase")
("gnuPG encrypt string @data for recipient fingerprint list @rcps" "Зашифрувати рядок @data GnuPG для списку відбитків отримувачів @rcps")
("gnuPG encrypt string @data with @passphrase" "Зашифрувати рядок @data GnuPG з @passphrase")
("gnuPG error: buffer encryption failed" "помилка gnuPG: помилка шифрування буфера")
("gnuPG error: cannot find suitable secret key to decrypt" "помилка gnuPG: не вдалося знайти відповідний секретний ключ для розшифрування")
("gnuPG executable" "Виконуваний файл GnuPG")
("gnuPG key:" "ключ gnuPG:")
("gnuPG public keys" "Публічні ключі GnuPG")
("gnuPG requires name and email to have at least 5 characters" "gnuPG вимагає, щоб імʼя та електронна адреса містили принаймні 5 символів")
("gnuPG secret keys" "Секретні ключі GnuPG")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs не супроводжується жодними юридичними гарантіями")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs підпадає під загальну публічну ліцензію GNU")
("go" "перейти")
("gothic" "готичний")
("go to anchor" "піти на якір")
("go to anchor or float" "йти на якір або плавати")
("go to anchor or footnote" "Перейти до якіря чи виноски")
("go to a position determined by @l inside the tree @t." "Перейти до позиції, визначеної @l всередині дерева @t.")
("go to first similar tag" "перейти до першого подібного тегу")
("go to float" "піти плавати")
("go to footnote" "перейти до виноски")
("go to last similar tag" "перейти до останнього подібного тегу")
("go to next position in history" "Перейти до наступної позиції в історії")
("go to next similar tag" "перейти до наступного подібного тегу")
("go to previous position in history" "Перейти до попередньої позиції в історії")
("go to previous similar tag" "перейти до попереднього подібного тегу")
("go to section" "перейти до розділу")
("go to the character at a given @row and @col" "перейти до символу за заданими @row і @col")
("go to the part with name @id" "Перейти до частини з імʼям @id")
("gradient..." "градієнт...")
("grain" "зерна")
("grammar for a minimal test language" "граматика для мінімальної тестової мови")
("granite" "граніт")
("graphical effects" "графічні ефекти")
("graphical interface" "графічний інтерфейс")
("graphical interface font scale" "шрифт графічного інтерфейсу")
("graphics" "графіка")
("graphics geometry" "графічна геометрія")
("graphics grids" "графічних сіток")
("grave" "гравіс")
("greater" "більше")
("greater or equal" "більше або дорівнює")
("greek" "грецька")
("greek:" "грецькі літери:")
("greek letter" "грецька літера")
("green" "зелений")
("grey" "сірий")
("greyed" "сірий")
("grid" "сітка")
("grid-curve intersections" "перехрестя кривої сітки")
("grid curves" "криві сітки")
("grid points" "точок сітки")
("group" "група")
("grouped" "згруповано")
("group of objects" "група обʼєктів")
("group scripts in @l." "Згрупувати скрипти в @l.")
("group/ungroup" "група / розгрупа")
("guarantee transparent source tracking" "гарантія прозорого відстеження джерела")
("half wide" "наполовину шириною")
("hand drawn" "намальований")
("happy typing" "щасливе друкування")
("has been aborted" "був перерваний")
("has completed its task" "завершив свою роботу")
("hat" "шапочка")
("header" "шапка")
("header and footer" "шапка і підвал")
("header bars" "панелі")
("headers" "заголовки")
("headheight:" "висота заголовка:")
("headsep:" "відступ заголовка:")
("hebrew" "іврит")
("height" "висота")
("height:" "висота:")
("height is exactly the specified height" "висота точно як задана")
("height is maximum of specified height and box height" "висота більша від заданої і висоти бокса")
("height is minimum of specified height and box height" "висота менша від заданої і висоти бокса")
("height magnification" "розтягання висоти")
("help" "допомога")
("help balloon" "балон підказки")
("helper routine for kbd-commands macro" "Допоміжна процедура для макроса kbd-commands")
("helper routine for kbd-map macro" "Допоміжна процедура для макросу kbd-map")
("helper routine for kbd-wildcards macro" "Допоміжна процедура для макросу kbd-wildcards")
("help me" "допоможіть мені")
("help us" "допоможіть нам")
("here" "тут")
("hidden" "прихований")
("highlight any of @lbs (matching @rbs) after a cursor movement" "Підсвітити будь-яку з @lbs (відповідні @rbs) після переміщення курсору")
("highlights innermost matching brackets around given @path" "Підсвітити внутрішні відповідні дужки навколо заданого @path")
("high resolution screen settings" "налаштування високої роздільності екрану")
("high resolution settings" "налаштування високої роздільності")
("history" "історія")
("H modifier" "модифікатор H")
("h modifier" "h модифікатор")
("home" "домашня сторінка")
("homepage" "домашня сторінка")
("homoglyph substitutions" "заміни гомогліфів")
("horizontal" "горизонтальний")
("horizontal:" "горизонтально:")
("horizontal alignment" "горизонтальне вирівнювання")
("horizontal cell alignment" "горизонтальне вирівнювання комірок")
("horizontal collapse distance" "горизонтальна відстань згортання")
("horizontal collapse distance:" "горизонтальна відстань згортання:")
("horizontal concatenation of list of LaTeX expressions" "Горизонтальне зʼєднання списку виразів LaTeX")
("horizontal ink separation" "горизонтальне розділення чорнила")
("horizontal layout of widgets" "Горизонтальне розташування віджетів")
("horizontally align cell to the base" "горизонтально вирівняти комірку до базового рівня")
("horizontally center the cell" "горизонтально центрувати комірку")
("horizontal margins" "горизонтальні поля")
("horizontal part" "горизонтальна частина")
("horizontal position" "горизонтальне положення")
("horizontal separator" "Горизонтальний роздільник")
("horizontal space" "горизонтальний проміжок")
("horizontal table alignment" "горизонтальне вирівнювання таблиці")
("how much longer may pages become" "наскільки довгими можуть стати сторінки")
("how much shorter may pages become" "наскільки короткими можуть стати сторінки")
("hpos" "горпоз")
("html" "html")
("html -> TeXmacs" "html -> TeXmacs")
("huge" "величезний")
("hungarian" "угорська")
("hybrid command" "гібридна команда")
("hyperlink" "гіперпосилання")
("hyphenate as" "дефіс як")
("hyphenation" "поділ слів")
("icelandic" "ісландська")
("icon" "ікона")
("if" "якщо")
(" iff " " тоді і тільки тоді, коли ")
("if hyphenated" "якщо дефіс")
("ignore" "ігнорувати")
("image" "зображення")
("image links" "посилання на зображення")
("image -> TeXmacs" "зображення -> TeXmacs")
("impact" "вплив")
("implementation" "реалізація")
("import" "імпортувати")
("import bibliography" "імпорт бібліографії")
("import database entry" "імпорт запису бази даних")
("imported bibliographic entries" "імпортовані бібліографічні записи")
("import entries in buffer" "імпорт записів у буфері")
("import entry" "імпортний запис")
("import file" "імпорт файлу")
("import GnuPG public keys" "Імпортувати публічні ключі GnuPG")
("import GnuPG secret keys" "Імпортувати секретні ключі GnuPG")
("import selected database entries" "імпорт вибраних записів бази даних")
("import selected entries" "імпорт вибраних записів")
("import selections as" "імпорт вибору як")
("import sessions" "імпорт сеансів")
("import sophisticated objects as pictures" "імпорт складних обʼєктів як зображень")
("improving the current implementation" "покращення поточної реалізації")
("inactive" "неактивний")
("inanimated" "неживий")
("inch" "дюйм")
("include" "включити")
("include a document" "включити документ")
("include file" "включити файл")
("inclusion into TeXmacs" "включення в TeXmacs")
("inclusions" "включення")
("incomplete entries found to be filled out" "знайдено незавершені записи, які потрібно заповнити")
("incorrect password; please try again." "неправильний пароль; спробуйте ще раз.")
("increase size" "збільшити розмір")
("indent" "відступ")
("indentation" "відступ")
("indentation flag" "прапорець відступу")
("indent a whole program" "відступити весь програмний код")
("indent paragraphs" "відступи абзаців")
("index" "покажчик")
("index entry" "запис у покажчику")
("index level" "рівень покажчика")
("indication" "позначення")
("inflate" "надутий")
("information" "інформація")
("informative flags" "інформативні прапорці")
("initialize" "ініціалізувати")
("initialize a new wallet" "Ініціалізувати новий гаманець")
("inits the value of @field in form @name to the @selected value and returns the list @l unmodified" "Ініціалізує значення @field у формі @name значенням @selected і повертає список @l без змін")
("ink here" "чорнило тут")
("ink in" "чорнило всередині")
("ink out" "чорнило зовні")
("inline" "вбудований")
("inline arguments" "вбудовані аргументи")
("inline code" "вбудований код")
("inline content" "вбудований вміст")
("inline formula" "вбудована формула")
("inner bottom" "внутрішнє дно")
("inner left" "внутрішній лівий")
("inner right" "внутрішній правий")
("inner top" "внутрішній верх")
("in popup windows" "у спливаючих вікнах")
("input:" "введення:")
("input command" "команда введення")
("input field" "поле введення")
("input mode" "режим введення")
("input options" "параметри введення")
("insert" "вставити")
("insert:" "вставити:")
("insert a balloon." "Вставити балон.")
("insert a big operator" "вставити великий оператор")
("insert a binary operation" "вставити бінарну операцію")
("insert a binary relation" "вставити бінарне відношення")
("insert a blackboard bold character" "вставити символ жирного дошки")
("insert a blank column at the right of the cursor." "Вставити порожній стовпець справа від курсора.")
("insert a blank row below cursor." "Вставити порожній рядок під курсором.")
("insert a bold calligraphic character" "вставити символ жирного каліграфічного шрифту")
("insert a bold character" "вставити жирний символ")
("insert above" "вставити зверху")
("insert abstract" "вставити абстракт")
("insert a calligraphic character" "вставити каліграфічний символ")
("insert a computer program" "вставити компʼютерну програму")
("insert a condition" "вставити умову")
("insert a control flow instruction" "вставити інструкцію керування потоком")
("insert a ʼfoldʼ environment" "Вставити середовище ʼfoldʼ")
("insert a fraction" "вставити дріб")
("insert a fraktur character" "вставити символ фрактури")
("insert a gap" "вставити проміжок")
("insert a greek character" "вставити грецький символ")
("insert a large left delimiter" "вставити великий лівий роздільник")
("insert a large right delimiter" "вставити великий правий роздільник")
("insert a large separator" "вставити великий роздільник")
("insert a left subscript" "вставити лівий підпис")
("insert a link" "вставити посилання")
("insert a list" "вставити список")
("insert a marginal note." "Вставити примітку на полях.")
("insert a miscellaneous symbol" "вставити різний символ")
("insert a multiple choice" "вставити декілька варіантів")
("insert an" "вставити")
("insert an accent" "вставити акцент")
("insert an answer" "вставити відповідь")
("insert an arrow" "вставити стрілку")
("insert a negation" "вставити заперечення")
("insert an enunciation" "вставити постановку")
("insert an environment" "вставити середовище")
("insert a new branch" "вставити нову гілку")
("insert a new entry" "вставити новий запис")
("insert a new item" "вставити новий елемент")
("insert an n" "вставити n")
("insert annotation" "вставити анотацію")
("insert an operation on tuples" "вставити операцію над кортежами")
("insert a note or a floating object" "вставити примітку або плаваючий обʼєкт")
("insert a numerical operation" "вставити числову операцію")
("insert a picture" "вставити зображення")
("insert appendix" "вставити додаток")
("insert a prominent piece of text" "вставити видний фрагмент тексту")
("insert a question" "вставити питання")
("insert arccos" "вставити arccos")
("insert arcsin" "вставити arcsin")
("insert arctan" "вставити arctan")
("insert arg" "вставити arg")
("insert argument" "вставити аргумент")
("insert a root" "вставити корінь")
("insert a script" "вставити скрипт")
("insert a section block" "вставити блок розділу")
("insert a square root" "вставити квадратний корінь")
("insert a table" "вставити таблицю")
("insert a table or a matrix" "вставити таблицю або матрицю")
("insert a TeXmacs symbol" "вставити символ TeXmacs")
("insert a textual operation" "вставити текстову операцію")
("insert a textual operator" "вставити текстовий оператор")
("insert author" "вставити автора")
("insert automatically generated content" "вставити автоматично згенерований вміст")
("insert a wide symbol above" "вставити широкий символ зверху")
("insert a wide symbol below" "вставити широкий символ знизу")
("insert below" "вставити знизу")
("insert big contour integral" "вставити великий контурний інтеграл")
("insert big coproduct" "вставити великий копродукт")
("insert big direct sum" "вставити велику пряму суму")
("insert big dotted point" "вставити велику крапку")
("insert big integral" "вставити великий інтеграл")
("insert big intersection" "вставити велике перетинання")
("insert big logical and" "вставити велике логічне І")
("insert big logical or" "вставити велике логічне АБО")
("insert big product" "вставити великий добуток")
("insert big square union" "вставити велике квадратне обʼєднання")
("insert big summation" "вставити велику суму")
("insert big tensor product" "вставити великий тензорний добуток")
("insert big union" "вставити велике обʼєднання")
("insert big union sum" "вставити велику суму-обʼєднання")
("insert big vertical space" "вставити великий вертикальний проміжок")
("insert binding @key ~> @val into wallet" "Вставити звʼязку @key ~> @val у гаманець")
("insert chapter" "вставити розділ")
("insert column" "вставити стовпець")
("insert column to the left" "вставити стовпець зліва")
("insert column to the right" "вставити стовпець справа")
("insert copyright and license information" "вставити інформацію про авторські права та ліцензію")
("insert cos" "вставити cos")
("insert cosh" "вставити cosh")
("insert cot" "вставити cot")
("insert coth" "вставити coth")
("insert csc" "вставити csc")
("insert deg" "вставити deg")
("insert det" "вставити det")
("insert dim" "вставити dim")
("insert dollar" "вставити долар")
("insert equation" "вставити рівняння")
("insert executable markup" "вставити виконавчу розмітку")
("insert exp" "вставити exp")
("insert explanatory item" "вставити пояснювальний елемент")
("insert field above" "вставити поле зверху")
("insert field below" "вставити поле знизу")
("insert fields" "вставити поля")
("insert footnote" "вставити виноску")
("insert formula" "вставити формулу")
("insert gcd" "вставити gcd")
("insert GnuPG decrypted block" "Вставити розшифрований блок GnuPG")
("insert GnuPG passphrase decrypted block" "Вставити розшифрований блок паролем GnuPG")
("insert hom" "вставити hom")
("insert horizontal interword space" "вставити горизонтальний міжслівний проміжок")
("insert image" "вставити зображення")
("insert inactive markup" "вставити неактивну розмітку")
("insert inf" "вставити inf")
("inserting control points" "вставлення контрольних точок")
("insert inline GnuPG decrypted region" "Вставити вбудовану розшифровану область GnuPG")
("insert inline GnuPG passphrase decrypted region" "Вставити розшифровану область паролем GnuPG")
("insert input field above" "вставити поле введення зверху")
("insert input field below" "вставити поле введення знизу")
("insert ker" "вставити ker")
("insert large delimiters" "вставити великі роздільники")
("insert last name" "вставити прізвище")
("insert left" "вставити ліворуч")
("insert lg" "вставити lg")
("insert lim" "вставити lim")
("insert liminf" "вставити liminf")
("insert limsup" "вставити limsup")
("insert ln" "вставити ln")
("insert log" "вставити log")
("insert macro" "вставити макрос")
("insert mathematics" "вставити математику")
("insert max" "вставити max")
("insert medium horizontal space" "вставити середній горизонтальний проміжок")
("insert medium vertical space" "вставити середній вертикальний проміжок")
("insert min" "вставити min")
("insert missing invisible operators" "вставити відсутні невидимі оператори")
("insert more names" "вставити більше імен")
("insert negative horizontal space" "вставити негативний горизонтальний проміжок")
("insert new item or number" "вставити новий елемент або номер")
("insert new rows or columns" "вставити нові рядки або стовпці")
("insert or delete rows or columns" "вставити або видалити рядки або стовпці")
("insert particle" "вставити частинку")
("insert plain text" "вставити звичайний текст")
("insert Pr" "вставити Pr")
("insert right" "вставити праворуч")
("insert row" "вставити рядок")
("insert row above" "вставити рядок над")
("insert row below" "вставити рядок нижче")
("insert sec" "вставити sec")
("insert section" "вставити розділ")
("insert sharp" "вставити решітку")
("insert similar above" "вставити подібне зверху")
("insert similar below" "вставити подібне знизу")
("insert similar block above" "вставити подібний блок зверху")
("insert similar block below" "вставити подібний блок знизу")
("insert sin" "вставити sin")
("insert sinh" "вставити sinh")
("insert small horizontal space" "вставити малий горизонтальний проміжок")
("insert small vertical space" "вставити малий вертикальний проміжок")
("insert structural markup" "вставити структурну розмітку")
("insert subsection" "вставити підрозділ")
("insert subsubsection" "вставити підпідрозділ")
("insert subtable" "вставити підтаблицю")
("insert sup" "вставити sup")
("insert symbol documentation" "вставити документацію символу")
("insert tan" "вставити tan")
("insert tanh" "вставити tanh")
("insert template" "вставити шаблон")
("insert text field" "вставити текстове поле")
("insert text field above" "вставити текстове поле зверху")
("insert text field below" "вставити текстове поле знизу")
("insert thick horizontal space" "вставити великий горизонтальний проміжок")
("insert title" "вставити заголовок")
("insert title after name" "вставити заголовок після імені")
("insert user interface related markup" "вставити розмітку, повʼязану з користувацьким інтерфейсом")
("insert value" "вставити значення")
("integrate" "інтегрувати")
("interactive command" "інтерактивна команда")
("interactive decryption" "Інтерактивне розшифрування")
("interactive decryption of all encrypted regions" "Інтерактивне розшифрування всіх зашифрованих областей")
("interactive GnuPG decryption" "Інтерактивне розшифрування GnuPG")
("interactive GnuPG encryption" "Інтерактивне шифрування GnuPG")
("interactive GnuPG passphrase decryption" "Інтерактивне розшифрування паролем GnuPG")
("interactive GnuPG passphrase encryption" "Інтерактивне шифрування паролем GnuPG")
("interactive passphrase decryption" "Інтерактивне розшифрування паролем")
("interactive passphrase encryption" "Інтерактивне шифрування паролем")
("interactive questions:" "інтерактивні запитання:")
("interactive questions" "інтерактивні питання")
("intercharacter compression" "міжсимвольне стиснення")
("intercharacter compression:" "стиснення міжсимвольних пробілів:")
("intercharacter stretching" "міжсимвольне розтягнення")
("intercharacter stretching:" "розтяжність міжсимвольних пробілів:")
("interfacing" "взаємодія")
("interfacing TeXmacs with other systems" "взаємодія TeXmacs з іншими системами")
("interjection" "вигук")
("interline separation" "інтерліньяж")
("interline space:" "міжрядковий простір:")
("interline space" "проміжок між рядками")
("internationalization" "інтернаціоналізація")
("interparagraph space:" "міжабзацний простір:")
("interparagraph space" "проміжок між параграфами")
("interrupted" "перервано")
("interrupt execution" "перервати виконання")
("introduction" "вступ")
("invalid multi-paragraph selection" "недійсний вибір кількох абзаців")
("invalid renaming" "недійсне перейменування")
("invert" "інвертувати")
("inverted breve" "перевернута брева")
("invisible" "невидимий")
("invisible citation" "невидиме цитування")
("invisible ending" "невидиме закінчення")
("invisible newline" "невидимий рядок")
("invisible opening" "невидимий відкриття")
("irish" "ірландська")
("is it the label of a primitive texmacs construct?" "Чи є це міткою примітивної конструкції texmacs?")
("ispell does not respond" "ispell не відповідає")
("ispell is already busy" "ispell вже зайнятий")
("is running" "виконується")
("is the cursor at the position determined by @l inside @t?" "Чи знаходиться курсор на позиції, визначеній @l всередині @t?")
("is the texmacs document fragment @x a block-level structure?" "Чи є фрагмент документа texmacs @x блоковою структурою?")
("is tuple" "є кортежем")
("is @x a null tmlength (zero value, unspecified unit)?" "Чи є @x нульовим tmlength (нульове значення, не визначена одиниця)?")
("is @x a, possible null, tmlength?" "Чи є @x, можливо, нульовим tmlength?")
("italian" "італійська")
("italic" "курсив")
("italic:" "курсив:")
("italic right" "курсив справа")
("item in an aligned list" "Елемент у вирівняному списку")
("itemize" "список")
("january" "січень")
("japanese" "японська")
("join selected cells" "обʼєднати вибрані комірки")
("july" "липень")
("jump in" "перейти всередину")
("jump to the first locus with a given identifier @id." "Перейти до першого локусу з заданим ідентифікатором @id.")
("jump to the url @u" "Перейти за посиланням @u")
("june" "червень")
("junior" "молодший")
("justified" "вирівняний")
("justify" "вирівнювати")
("justify text" "вирівняти текст")
("keep evaluated expressions" "зберігати оцінені вирази")
("keep local" "зберігати локально")
("keep remote" "зберігати віддалено")
("keep track of source code" "відстежувати джерельний код")
("keep unfolded" "зберігати розгорнутим")
("key" "клавіша")
("keyboard" "клавіатура")
("keyboard configuration" "конфігурація клавіатури")
("keyboard equivalent" "еквівалент клавіатури")
("keyboard modifiers" "модифікатори клавіатури")
("keyboard shortcut" "клавіатурне скорочення")
("keymaps" "мапи клавіш")
("keyword" "ключове слово")
("keywords" "ключові слова")
("kill" "завершити")
("known bugs" "відомі помилки")
("label" "мітка")
("landscape" "горизонтальна")
("language" "мова")
("laptop presentations" "презентації на ноутбуках")
("large" "великий")
("large cells" "великі комірки")
("large closing bracket" "велика закривна дужка")
("large delimiter" "великий роздільник")
("large displayed" "великий відображений")
("large displayed fraction" "великий відображений дріб")
("large opening bracket" "велика відкривна дужка")
("large separator" "великий роздільник")
("large tables" "великі таблиці")
("last" "останні")
("last check:" "остання перевірка:")
("last difference" "остання різниця")
("last error" "остання помилка")
("last field" "останнє поле")
("last indentation" "останній відступ")
("last name" "прізвище")
("last occurrence" "останнє входження")
("last page" "остання сторінка")
("last similar" "останній подібний")
("latex command" "команда LaTeX")
("LaTeX" "LaTeX")
("laTeX" "laTeX")
("laTeX -> TeXmacs" "laTeX -> TeXmacs")
("latin" "латинська")
("layout" "розміщення")
("lcm" "НСД")
("left" "лівий")
("left:" "ліво:")
("left aligned" "лівий вирівняний")
("left arrow" "стрілка вліво")
("left axis" "ліва вісь")
("left baseline" "ліва базова лінія")
("left border" "лівий край")
("left bottom" "лівий нижній кут")
("left cell border" "ліва межа комірки")
("left cell padding" "відступ зліва комірки")
("left center" "лівий центр")
("left click: add point; Right click: undo" "ліва кнопка: додати точку; Права кнопка: скасувати")
("left click: finish; Right click: undo" "ліва кнопка: завершити; Права кнопка: скасувати")
("left click: new object" "ліва кнопка: новий обʼєкт")
("left click: operate" "ліва кнопка: виконати")
("left down" "ліворуч вниз")
("left margin:" "ліва межа:")
("left margin" "ліве поле")
("left on even pages" "зліва на парних сторінках")
("left padding" "ліве заповнення")
("left prime" "лівий прим")
("left-right arrow" "стрілка вліво-вправо")
("left slanted" "лівий нахилений")
("left subscript" "лівий нижній індекс")
("left superscript" "лівий верхній індекс")
("left surrounding" "ліве оточення")
("left table border" "ліва межа таблиці")
("left table padding" "відступ зліва таблиці")
("left top" "лівий верхній кут")
("left up" "ліворуч вгору")
("leftwards" "вліво")
("legal" "легальний")
("lemma" "лема")
("length" "довжина")
("less" "менше")
("less or equal" "менше або дорівнює")
("let* primitive for content generation" "Let* примітив для генерації вмісту")
("letter" "лист")
("let the environment float" "дозволити середовищу плавати")
("license" "ліцензія")
("light" "світлий")
("light grey" "світло-сірий")
("limit: " "обмеження: ")
("limitations" "обмеження")
("limits" "ліміти")
("line" "рядок")
("linear 2D" "лінійний 2D")
("linear algebra" "лінійна алгебра")
("line break" "розрив рядка")
("line breaking" "розрив рядка")
("line breaking:" "розрив рядків:")
("lines around" "рядків навколо")
("line stretch" "розтягання рядка")
("linewidth:" "товщина лінії:")
("line wrapping" "перенесення рядка")
("line wrapping:" "перенесення рядків:")
("link" "посилання")
("link image" "посилання на зображення")
("link image and copies as" "посилання на зображення та копії як")
("link image as" "посилання на зображення як")
("linking tool" "інструмент зʼєднання")
("link mode" "режим посилання")
("link to URL" "посилання на URL")
("list" "список")
("list all entries of the wallet" "Перерахувати всі записи гаманця")
("list of exported symbols in @module" "Список експортованих символів у @module")
("list of figures" "список малюнків")
("list of tables" "список таблиць")
("list the fingerprints of the public keyring" "Перерахувати відбитки публічного ключового кільця")
("list the fingerprints of the secret keyring" "Перерахувати відбитки секретного ключового кільця")
("live" "живий")
("live input-output" "живий введення-виведення")
("load" "завантажити")
("load a buffer or switch to it if already open" "Завантажити буфер або перемкнутися на нього, якщо він вже відкритий")
("load a file" "завантажити файл")
("load and decrypt object from @url with @passphrase" "Завантажити та розшифрувати обʼєкт з @url з @passphrase")
("load and decrypt string from @url with @passphrase" "Завантажити та розшифрувати рядок з @url з @passphrase")
("load buffer" "завантажити буфер")
("load Doxygen tag file." "Завантажити файл тегів Doxygen.")
("loaded" "завантажений")
("load file" "завантажити файл")
("load file which contains locus with a given @id." "Завантажити файл, який містить локус з заданим @id.")
("load help file" "завантажити файл довідки")
("load html file" "завантажити файл з HTML")
("load image" "завантажити зображення")
("loading" "завантаження")
("load in new window" "завантажити у нове вікно")
("load LaTeX file" "завантажити LaTeX файл")
("load latex file" "завантажити LaTeX файл")
("load more recent autosave file" "завантажити більш свіжий автозбережений файл")
("load remote file" "завантажити віддалений файл")
("load TeX file" "завантажити файл TeX")
("load tex file" "завантажити файл TeX")
("load TeXmacs file" "завантажити файл TeXmacs")
("load TeXmacs style file" "завантажити файл стилю TeXmacs")
("load the file @u into the scheme interpreter" "Завантажити файл @u до інтерпретатора схеми")
("load verbatim file" "завантажити буквальний файл")
("local:" "локальний:")
("local destination:" "локальне призначення:")
("local entries" "локальні записи")
("local source:" "локальне джерело:")
("loci" "локуси")
("locus" "локус")
("locus color" "колір локуса")
("locus rendering" "відображення локусу")
("logarithm" "логарифм")
("logarithmic" "логарифмічний")
("logarithmic base" "логарифмічна основа")
("logarithms" "логарифми")
("logging in" "вхід")
("logical and" "логічне І")
("logical implication" "логічна імплікація")
("logical not" "логічне заперечення")
("logical or" "логічне або")
("login" "вхід")
("logout" "вихід")
("long" "довгий")
("long macro" "довгий макрос")
("long text" "довгий текст")
("look and feel:" "вигляд і відчуття:")
("look and feel" "вигляд та поведінка")
("look for more fonts" "шукати більше шрифтів")
("look up" "знайти")
("loops" "цикли")
("lower border" "нижній край")
("macro" "макро")
("macro argument" "аргумент макросу")
("macro definition" "визначення макросу")
("macro name" "імʼя макросу")
("macros" "макроси")
("magenta" "фіолетовий")
("magic" "магічний")
("magnification" "збільшення")
("magnified" "збільшений")
("magnify horizontally" "збільшити по горизонталі")
("magnify horizontally:" "збільшити по горизонталі:")
("magnify vertically" "збільшити по вертикалі")
("magnify vertically:" "збільшити по вертикалі:")
("main" "головний")
("main icon bar" "головна смуга іконок")
("main presentation style:" "основний стиль відображення:")
("main presentation style" "основний стиль презентації")
("main toolbar" "головна панель")
("major changes" "головні зміни")
("make a cached widget" "Створити кешований віджет")
("make a choice list" "Створити список вибору")
("make acute" "зробити acute")
("make a letter environment" "створити середовище для листа")
("make a link of type @type." "Створити посилання типу @type.")
("make a menu group" "Створити групу меню")
("make a menu symbol" "Створити символ меню")
("make a multiple choice field for the current form" "Створити поле з множинним вибором для поточної форми")
("make a multiple choice list" "Створити список з множинним вибором")
("make a multi-slide presentation" "створити багатопозиційну презентацію")
("make an enumeration field for the current form" "Створити поле перерахування для поточної форми")
("make an ink widget" "Створити віджет для рисування")
("make an insertion of type @s." "Зробити вставку типу @s.")
("make a page insertion" "зробити вставку сторінки")
("make a refreshable widget" "Створити віджет, який можна оновити")
("make a refresh widget" "Створити віджет оновлення")
("make a scrollable choice list with a filter on top" "Створити прокручуваний список вибору з фільтром зверху")
("make a scrollable widget" "Створити віджет з прокруткою")
("make a single choice field for the current form" "Створити поле з одним вибором для поточної форми")
("make a subscript" "зробити нижній індекс")
("make a superscript" "зробити верхній індекс")
("make a textual input field for the current form" "Створити текстове поле вводу для поточної форми")
("make a toggle field for the current form" "Створити поле перемикача для поточної форми")
("make a tree view of the data" "Створити дерево перегляду даних")
("make balloon" "Створити балон")
("make bar" "зробити смугу")
("make button" "Створити кнопку")
("make check" "зробити перевірку")
("make check" "Створити прапорець")
("make color picker" "Створити вибір кольору")
("make dynamic link to another widget" "Створити динамічне посилання на інший віджет")
("make dynamic widgets" "Створити динамічні віджети")
("make extensible colored glue" "Створити розширювальний кольоровий клей")
("make extensible glue" "Створити розширювальний клей")
("make floating" "зробити плаваючим")
("make form" "Створити форму")
("make fraction" "зробити дріб")
("make grave" "зробити грав")
("make hat" "зробити шапку")
("make hidden part with identifier @id visible" "Зробити приховану частину з ідентифікатором @id видимою")
("make icon" "Створити піктограму")
("make input enumeration field" "Створити поле перерахування вводу")
("make input field" "Створити поле вводу")
("make input toggle" "Створити перемикач вводу")
("make invisible" "Зробити невидимим")
("make label" "зробити мітку")
("make link" "створити посилання")
("make minibar" "Створити міні-панель")
("make mini widgets" "Створити міні-віджети")
("make negation" "зробити заперечення")
("make non floating" "зробити неплаваючим")
("make opaque" "зробити непрозорим")
("make page reference" "зробити посилання на сторінку")
("make possibly inert (whence greyed) widgets" "Створити можливо нерухомі (тому сірі) віджети")
("make pulldown button" "Створити кнопку з випадаючим списком вниз")
("make pullright button" "Створити кнопку з випадаючим списком вправо")
("make reference" "зробити посилання")
("make shortcut" "Створити ярлик")
("make square root" "зробити квадратний корінь")
("make TeXmacs input field" "Створити поле вводу TeXmacs")
("make TeXmacs output field" "Створити поле виводу TeXmacs")
("make text" "Створити текст")
("make text concatenation" "Створити зʼєднання тексту")
("make text to be translated with arguments" "Створити текст для перекладу з аргументами")
("make the node @(tree-ref t . l) correct" "Зробити вузол @(tree-ref t . l) правильним")
("make tilde" "зробити тильду")
("make title" "зробити заголовок")
("make transparent" "зробити прозорим")
("make vector" "зробити вектор")
("make verbatim text" "Створити текст без форматування")
("make widgets" "Створити віджети")
("make ʼwithʼ with one or more paragraphs as its scope" "Зробити ʼзʼ з одним або декількома абзацами як його область")
("making donations" "надання пожертв")
("manila paper" "манільський папір")
("manual" "посібник")
("manually correct selected formula or all formulas in document" "Вручну виправити вибрану формулу або всі формули в документі")
("map arguments" "аргументи карти")
("map to" "відобразити на")
("march" "березень")
("marginal" "на полях")
("marginal note" "примітка на полях")
("marginal note sep" "роздільник замітки на полях")
("marginal note width" "ширина замітки на полях")
("margins" "поля")
("margins as on paper" "поля як на папері")
("margins from width" "поля від ширини")
("margins on paper" "поля на папері")
("margins on screen" "поля на екрані")
("marked" "позначено")
("master" "головний")
("master file" "головний файл")
("material" "матеріал")
("math" "мат")
("mathematical" "математичний")
("mathematical and customized input" "математичний та налаштований ввід")
("mathematical font" "математичний шрифт")
("mathematical formulas" "математичні формули")
("mathematical input" "математичний ввід")
("mathematical output" "математичний вивід")
("mathematical typesetting" "математична верстка")
("mathematics" "математика")
("mathematics:" "математика:")
("math font" "математичний шрифт")
("math font family" "сімейство математичних шрифтів")
("math font series" "серія математичних шрифтів")
("math font shape" "форма математичного шрифту")
("matrices" "матриці")
("matrix" "матриця")
("maximal" "максимальний")
("maximal cell height" "максимальна висота комірки")
("maximal clustering" "максимальна кластеризація")
("maximal number of columns" "максимальна кількість стовпців")
("maximal number of rows" "максимальна кількість рядків")
("maximal table height" "максимальна висота таблиці")
("maximal table width" "максимальна ширина таблиці")
("maximum" "максимум")
("maximum:" "максимум:")
("maximum mode" "максимальний режим")
("may" "травень")
("meander" "меандр")
("medium" "середній")
("medium skip" "середній пропуск")
("meminfo" "meminfo")
("memory" "памʼять")
("memory usage" "використання памʼяті")
("menu" "меню")
("menu:" "меню:")
("merge" "обʼєднати")
("merge lines into paragraphs unless separated by blank lines" "обʼєднати рядки в абзаци, якщо вони не розділені порожніми рядками")
("message" "повідомлення")
("message:" "повідомлення:")
("messages" "повідомлення")
("messy" "брудний")
("meta data" "метадані")
("metadata" "метадані")
("meta key" "мета-клавіша")
("metal" "метал")
("middle" "середній")
("middle baseline" "середня базова лінія")
("minimal" "мінімальний")
("minimal cell height" "мінімальна висота комірки")
("minimal cell width" "мінімальна ширина комірки")
("minimal line separation" "мінімальний відступ між лініями")
("minimal line separation:" "мінімальний міжрядковий простір:")
("minimal number of columns" "мінімальна кількість стовпців")
("minimal number of rows" "мінімальна кількість рядків")
("minimal table height" "мінімальна висота таблиці")
("minimal table width" "мінімальна ширина таблиці")
("minimum" "мінімум")
("minimum:" "мінімум:")
("minimum mode" "мінімальний режим")
("minus" "мінус")
("mirror" "дзеркало")
("miscellaneous" "різноманітні")
("miscellaneous features" "різноманітні функції")
("miscellanous" "різне")
("M modifier" "модифікатор M")
("m modifier" "модифікатор m")
("mod" "модуль")
("mode" "режим")
("mode dependent icons" "значки, залежні від режиму")
("modifier" "модифікатор")
("modify cell alignment" "змінити вирівнювання комірки")
("modify cell border" "змінити вигляд межі комірки")
("modify cell padding" "змінити заповнення комірки")
("modify cell size" "змінити розмір комірки")
("modify remote live document" "змінити віддалений живий документ")
("modify table border" "змінити вигляд межі таблиці")
("modify table padding" "змінити заповнення таблиці")
("module" "модуль")
("mongolian" "монгольська")
("monospaced" "однорядковий")
("more information about GNU TeXmacs can be found in the Help" "Додаткову інформацію про GNU TeXmacs можна знайти у довідці")
("more information about GNU TeXmacs can be found in the help" "додаткову інформацію про GNU TeXmacs можна знайти у довідці")
("more information about GNU TeXmacs can be found in the Help->About menu" "Додаткову інформацію про GNU TeXmacs можна знайти у меню Довідка->Про")
("mosaic" "мозаїка")
("motion" "рух")
("mouse over balloon" "балон під мишкою")
("mouse over balloon*" "балон під мишкою*")
("mouse over object" "наведення миші на обʼєкт")
("move" "переміщення")
("move down" "переміститися вниз")
("move object" "пересунути обʼєкт")
("move objects" "переміщення обʼєктів")
("move over object on which to operate" "наведення миші на обʼєкт, з яким працювати")
("move to the right when finished" "переміститися вправо після завершення")
("move up" "переміститися вгору")
("multiline" "багаторядковий")
("multiline input" "багаторядковий ввід")
("multiple choice" "множинний вибір")
("multiple root" "декілька коренів")
("multiplication" "множення")
("mutator tags" "теги мутаторів")
("my documents" "мої документи")
("name" "імʼя")
("name:" "імʼя:")
("named" "іменоване")
("natbib" "natbib")
("navigation options" "опції навігації")
("negation" "заперечення")
("never" "ніколи")
("new" "новий")
("new account" "новий обліковий запис")
("new bibliography dialogue" "новий діалог бібліографії")
("new buffer" "новий буфер")
("new column" "новий стовпець")
("new context macro..." "новий контекстний макрос...")
("new document" "новий документ")
("new double page" "нова подвійна сторінка")
("new double page before" "нова подвійна сторінка перед")
("new entry" "новий запис")
("newer version" "новіша версія")
("new identity" "нова ідентичність")
("new item" "новий елемент")
("new line" "новий рядок")
("new locus" "новий локус")
("new macro" "новий макрос")
("new number" "новий номер")
("new page" "нова сторінка")
("new page before" "нова сторінка перед")
("new paragraph" "новий параграф")
("new passphrase" "нова фраза-пароль")
("new passphrase:" "новий пароль:")
("new remote directory" "новий віддалений каталог")
("new remote file" "новий віддалений файл")
("new roman" "новий роман")
("new row" "новий рядок")
("new style fonts" "шрифти нового стилю")
("new style page breaking" "розрив сторінки нового стилю")
("new table" "нова таблиця")
("new version" "нова версія")
("new wallet passphrase:" "нова фраза-пароль гаманця:")
("new window" "нове вікно")
("next" "далі")
("next chunk" "наступний фрагмент")
("next difference" "наступна різниця")
("next error" "наступна помилка")
("next field" "наступне поле")
("next line" "наступний рядок")
("next occurrence" "наступне входження")
("next screen" "наступний екран")
("next similar" "наступний подібний")
("no" "Ні")
("no animation" "без анімації")
("no changes need to be saved" "нема змін, що потребують збереження")
("no clustering" "немає кластеризації")
("no completions" "немає завершень")
("no dictionary for" "нема словника для")
("no errors have been corrected" "жодні помилки не були виправлені")
("no first indentation" "не робити першого відступу")
("no grid" "немає сітки")
("no indentation" "без відступу")
("no last indentation" "не робити останнього відступу")
("no line break" "не розривати рядок")
("no matches found" "нічого не знайдено")
("no matches found for" "не знайдено відповідностей для")
("no more matches for" "більше нічого не знайдено")
("no more redo information available" "більше нема доступної інформації для повернення")
("no more undo information available" "більше нема доступної інформації для відновлення")
("no name" "без назви")
("non-correcting constructor of horizontal concatenations." "Конструктор горизонтального зʼєднання без корекції.")
("none" "жодного")
("no new public key in document!" "немає нового відкритого ключа в документі!")
("no new public key in document" "немає нового відкритого ключа в документі")
("no page break" "немає розриву сторінки")
("no page break after" "не розривати сторінку після")
("no page break before" "не розривати сторінку перед")
("no page numbers" "немає номерів сторінок")
("no parent" "немає батьків")
("normal" "нормальний")
("normalization of the table @t" "Нормалізація таблиці @t")
("normal loci" "нормальні локуси")
("norwegian" "норвезька")
("no selection" "немає вибору")
("no spelling errors" "немає орфографічних помилок")
("no spelling errors found in text" "у тексті не знайдено помилок правопису")
("no style" "нема стилю")
("not" "не")
("not allowed to remove home directory" "не дозволяється видаляти домашній каталог")
("notation" "нотація")
("not connected to server" "не підключено до сервера")
("note" "примітка")
("notebook" "записна книжка")
("not equal" "не дорівнює")
("not found" "не знайдено")
("notify that the preference @which was changed" "Повідомити, що налаштування @which було змінено")
("not yet implemented" "ще не реалізовано")
("november" "листопад")
("n-th" "n-ий")
("n-th root" "корінь n-ої степені")
("number" "число")
("numbered" "нумероване")
("numbered equation" "пронумероване рівняння")
("numbered equations" "пронумеровані рівняння")
("number equation" "нумерація рівняння")
("numbering" "нумерація")
("number of columns" "кількість стовпців")
("number of columns:" "кількість стовпців:")
("number of polar steps" "кількість полярних кроків")
("number of subunit steps" "кількість кроків підрозділу")
("numerator" "чисельник")
("numeric" "числовий")
("numeric spreadsheet" "числова електронна таблиця")
("objectives" "цілі")
("obtain the preamble of the current buffer" "Отримати преамбулу поточного буфера")
("obtain the preamble of the document tree @t" "Отримати преамбулу дерева документа @t")
("occurrences" "випадки")
("october" "жовтень")
("odd page" "непарна сторінка")
("odd page footer" "підвал непарних сторінок")
("odd page header" "шапка непарних сторінок")
("(Odd page) Left:" "(Непарна сторінка) Зліва:")
("odd page left margin" "ліва межа непарної сторінки")
("odd page margin" "поля непарних сторінок")
("(Odd page) Right:" "(Непарна сторінка) Справа:")
("odd page right margin" "права межа непарної сторінки")
("(odd pages)" "(непарні сторінки)")
("odd pages" "непарні сторінки")
("odd page shift:" "зсув непарних сторінок:")
("odd page shift" "зсув непарної сторінки")
("odd page text" "текст непарних сторінок")
("oddsidemargin:" "ліва межа непарних сторінок:")
("off" "вимк")
("of fingerprint" "відбиток пальця")
("OK" "Гаразд")
("ok" "гаразд")
("old english" "староанглійська")
("older version" "старіша версія")
("old slavonic" "старословʼянська")
("old style" "старий стиль")
("old version" "стара версія")
("on" "увімкнено")
("on cells" "на комірках")
("on columns" "на стовпцях")
("one column" "один стовпець")
("one error has been corrected" "одна помилка була виправлена")
("one icon tab of an icon tab bar" "Одна іконка вкладки панелі вкладок з іконками")
("one lower case letter, one non alpha-numeric symbol" "одна маленька літера, один не буквено-цифровий символ")
("one lower case letter, one non alpha-numeric symbol." "одну малу літеру, один неалфавітно-цифровий символ.")
("on entire table" "на всій таблиці")
("one numeric character, one upper case letter" "один цифровий символ, одна велика літера")
("one numeric character, one upper case letter," "один числовий символ, одну велику літеру,")
("one spelling error has been corrected" "одна помилка правопису виправлена")
("one tab of a tab bar" "Одна вкладка панелі вкладок")
("online documentation" "документація у Тенетах")
("online help" "допомога у Тенетах")
("only convert changes when re-importing" "конвертувати зміни лише при повторному імпорту")
("only convert changes with respect to imported version" "конвертувати зміни лише щодо імпортованої версії")
("only convert changes with respect to tracked version" "конвертувати зміни лише щодо відстежуваної версії")
("only implemented for complete subtrees" "реалізовано лише для повних підрядків")
("only inline tags" "лише вбудовані теги")
("only keep folded" "зберігати лише складеними")
("only keep unfolded" "зберігати лише розгорнутими")
("only show semantic focus" "показувати лише семантичний фокус")
("on rows" "на рядках")
("on the footer" "у нижньому колонтитулі")
("on your system and set it up from the \"Security\" tab." "на вашій системі та налаштувати його з вкладки \"Безпека\".")
("on your system and set it up from the \"Security\" tab" "на вашій системі та налаштуйте його на вкладці «Безпека»")
("opacity" "непрозорість")
("Open" "Відкрити")
("open" "відкрити")
("open a new buffer" "відкрити новий буфер")
("open a new file" "Відкрити новий файл")
("open bibliography" "відкрити бібліографію")
("open identities" "відкриті ідентичності")
("opening" "відкриваю")
("open in new window" "відкрити в новому вікні")
("open key manager" "відкрити менеджер ключів")
("open licence agreement" "відкрита ліцензійна угода")
("open mailbox" "відкрита поштова скринька")
("open module browser" "відкрити браузер модулів")
("open new window" "відкрити нове вікно")
("open on errors" "відкривати при помилці")
("open on warnings" "відкривати при попередженні")
("opens a help buffer for the scheme symbol @word" "Відкриває буфер довідки для символу схеми @word")
("opens a help buffer with a list of all TeXmacs modules" "Відкриває буфер довідки зі списком усіх модулів TeXmacs")
("opens a help buffer with a list of all tm-defined symbols" "Відкриває буфер довідки зі списком усіх символів, визначених tm")
("open symbol browser" "відкрити браузер символів")
("open tool in separate window" "відкрити інструмент в окремому вікні")
("operation mode" "режим роботи")
("operation on named selection" "операція над іменованим виділенням")
("operation on primary selection" "операція над основним виділенням")
("operation on secondary selection" "операція над вторинним виділенням")
("operation on ternary selection" "операція над третинним виділенням")
("operators for a minimal test language" "оператори для мінімальної тестової мови")
("optical" "оптичний")
("option" "опція")
("options" "опції")
(" or " " або ")
("or" "або")
("orange" "помаранчевий")
("order" "порядок")
("order: " "порядок: ")
("ordinary symbol" "звичайний символ")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "або вкажіть повний шлях до команди «gpg» або «gpg2»")
("or give the complete path to the \"gpg\" or \"gpg2\" command." "або вкажіть повний шлях до команди \"gpg\" або \"gpg2\".")
("orientation" "орієнтація")
("orientation:" "орієнтація:")
("origin" "походження")
("original welcome message" "оригінальне привітальне повідомлення")
("ornamented" "орнаментовані")
("other" "інший")
("other login" "інший логін")
("other package" "інший пакет")
("other pages" "інші сторінки")
("other projects" "інші проекти")
("other style" "інший стиль")
("outer bottom" "зовнішнє дно")
("outer left" "зовнішній лівий")
("outer right" "зовнішній правий")
("outer top" "зовнішній верх")
("outline" "контур")
("outlined" "окреслені")
("outlined emboss" "окреслений рельєф")
("outlined engrave" "окреслена гравюра")
("outlined roman" "обведений роман")
("output options" "параметри виводу")
("oval" "овал")
("over" "над")
("overbrace" "переборщик")
("overlap" "перекриття")
("overlay" "накладення")
("overlays" "накладки")
("overline" "перекреслення")
("overlined" "накреслений")
("overview of the scheme extension language" "огляд мови розширення схеми")
("padded" "підкладки")
("padding" "заповнення")
("page" "сторінка")
("page background" "фон сторінки")
("page background:" "фон сторінки:")
("page bottom margin" "нижнє поле сторінки")
("page break" "розрив сторінки")
("page break after" "перерва сторінки після")
("page break before" "розрив сторінки перед")
("page breaking algorithm" "алгоритм розбиття сторінки")
("page breaking algorithm:" "алгоритм розриву сторінки:")
("page float sep" "розд. плаваючого на сторінці")
("page headers and footers" "заголовки та підзаголовки сторінки")
("page height" "висота сторінки")
("page height:" "висота сторінки:")
("page insertion" "вставка сторінки")
("page layout" "розміщення на сторінці")
("page number" "номер сторінки")
("page numbering" "нумерація сторінок")
("page number rendering" "відображення номера сторінки")
("page number rendering:" "відображення номера сторінки:")
("page number text" "текст номера сторінки")
("page reference" "посилання на сторінку")
("page rendering:" "відображення сторінки:")
("page rendering" "візуалізація сторінки")
("page right margin" "праве поле сторінки")
("page setup" "налаштування сторінки")
("page top margin" "верхнє поле сторінки")
("page type" "тип сторінки")
("page type:" "тип сторінки:")
("page width" "ширина сторінки")
("page width:" "ширина сторінки:")
("pale blue" "злегка блакитний")
("palette" "палітра")
("panorama" "панорама")
("paper" "папір")
("paper type" "тип паперу")
("paper type:" "тип паперу:")
("papyrus" "папірус")
("paragraph" "параграф")
("paragraph mode" "режим параграфу")
("paragraphs" "абзаців")
("paragraph width" "ширина параграфу")
("parametric curve" "параметрична крива")
("parametric surface" "параметрична поверхня")
("parchment" "пергамент")
("parenthesis" "дужки")
("parenthesized" "в дужках")
("parse a TeXmacs XML document @s." "Розбирає документ TeXmacs XML @s.")
("parse @fname in @basedir and its sub-branches, collecting docs." "Розібрати @fname в @basedir та його підгіллях, збираючи документи.")
("part" "частина")
("particle" "частинка")
("passphrase:" "пароль:")
("passphrase decrypt all regions in buffer" "Розшифрувати всі області у буфері паролем")
("passphrase decrypt current block" "Розшифрувати поточний блок паролем")
("passphrase decrypt current inline region" "Розшифрувати поточну вбудовану область паролем")
("passphrase decrypt @t with @passphrase" "Розшифрувати @t паролем @passphrase")
("passphrase encrypt current block" "Зашифрувати поточний блок паролем")
("passphrase encrypt current inline region" "Зашифрувати поточну вбудовану область паролем")
("passphrase encryption" "шифрування парольної фрази")
("passphrase encrypt @t with @passphrase" "Зашифрувати @t паролем @passphrase")
("passphrases are expected to have at least: 8 characters" "Очікується, що у парольних фразах буде принаймні 8 символів")
("passphrases are expected to have at least: 8 characters," "паролі повинні містити принаймні 8 символів,")
("passphrase should have at least 8 characters:" "фраза-пароль повинна містити принаймні 8 символів:")
("passphrases mismatch" "невідповідність парольних фраз")
("passphrase wallet facilities are not currently available" "засоби для гаманця з парольною фразою наразі недоступні")
("passphrase wallet facilities are not currently available." "можливості гаманця фраз-паролів в даний момент недоступні.")
("password:" "пароль:")
("past changes" "минулі зміни")
("paste" "вставити")
("paste from" "вставити з")
("pastel" "пастель")
("paste text" "вставити текст")
("path" "шлях")
("pattern" "візерунок")
("pause" "пауза")
("pause:" "пауза:")
("pdf" "pdf")
("pdf version number:" "номер версії pdf:")
("pen width" "ширина ручки")
("perform operations on cells" "виконати операції над комірками")
("perform operations on columns" "виконати операції над колонками")
("perform operations on entire table" "виконати операції над усією таблицею")
("perform operations on rows" "виконати операції над рядками")
("permanent" "постійний")
("permanent footer" "постійний колонтитул")
("permanent header" "постійний заголовок")
("permanently add to dictionary" "назавжди додати до словника")
("permanently insert into dictionary" "назавжди вставити в словник")
("permissions" "дозволи")
("person" "особа")
("personal dictionary has been modified" "особистий словник змінився")
("phantasy" "фантазія")
("phantom" "фантом")
("phantom float" "плаваючий фантом")
("phantoms" "фантоми")
("philosophy" "філософія")
("phoenician" "фінікійська")
("phonetic" "фонетичний")
("physics and astronomy class" "клас фізики та астрономії")
("picture" "малюнок")
("pictures" "малюнки")
("pine" "сосна")
("pink" "рожевий")
("places an image of the current selection on the clipboard" "Розміщує зображення поточного виділення в буфер обміну")
("plain" "простий")
("plain block" "простий блок")
("plain boxes" "прості коробки")
("plain circles" "прості кола")
("plain tabular" "проста таблиця")
("planned changes" "заплановані зміни")
("plans for the future" "плани на майбутнє")
("play" "відтворення")
("play:" "відтворити:")
("play animation" "відтворити анімацію")
("please" "будь ласка")
("please install GnuPG software from https://www.gnupg.org" "будь ласка, встановіть програмне забезпечення GnuPG з https://www.gnupg.org")
("please install GnuPG software from https://www.gnupg.org/" "будь ласка, встановіть програмне забезпечення GnuPG з https://www.gnupg.org/")
("please install GnuPG software from https://www.gnupg.org/," "будь ласка, встановіть програмне забезпечення GnuPG з https://www.gnupg.org/,")
("please wait" "будь ласка, зачекайте")
("plot" "сюжет")
("plugin" "плагін")
("plug-ins" "плагіни")
("plugins" "плагіни")
("plural" "множина")
("plus" "плюс")
("point" "точка")
("polar" "полярний")
("polish" "польська")
("polygon" "багатокутник")
("pop server settings" "налаштування сервера POP")
("pops up the help window for the innermost TeXmacs macro" "Відкриває вікно довідки для найвнутрішнішого макросу TeXmacs")
("pops up the help window for the scheme symbol @word" "Відображає вікно довідки для символу схеми @word")
("porting TeXmacs to other platforms" "перенесення TeXmacs на інші платформи")
("portrait" "портретна")
("portuguese" "португальська")
("position" "розташування")
("position float" "розташувати плаваючий")
("position floating object" "розташуватиплаваючий обʼєкт")
("position of marginal note" "розташувати примітку на полях")
("position the table" "розташувати таблицю")
("poster formats" "формати плакатів")
("poster theme" "тема плаката")
("postfix" "постфікс")
("postscript" "постскрипт")
("postscript image" "постскриптове зображення")
("pre-alpha release" "пре-альфа версія")
("preamble" "преамбула")
("preamble mode" "режим преамбули")
("preferences" "налаштування")
("preferences for editing mathematical formulas" "налаштування для редагування математичних формул")
("preferences for tag" "налаштування для тегу")
("prefix" "префікс")
("presentation" "презентація")
("presentation mode" "режим презентації")
("presentation tag" "тег презентації")
("presentation tool" "інструмент презентації")
("preserve" "зберегти")
("preserve tags" "зберегти теги")
("pretty tree output" "гарний вивід дерева")
("preview" "попередній перегляд")
("preview before printing" "переглянути перед друкуванням")
("preview command" "команда попереднього перегляду")
("preview command:" "команда попереднього перегляду:")
("preview with ghostview" "переглянути за допомогою ghostview")
("previous" "попередній")
("previous difference" "попередня різниця")
("previous error" "попередня помилка")
("previous field" "попереднє поле")
("previous occurrence" "попереднє входження")
("previous screen" "попередній екран")
("previous similar" "попередній аналогічний")
("primary" "первинний")
("prime" "просте число")
("primitive or macro" "примітивний або макрос")
("print" "друкувати")
("print all" "друкувати все")
("print all to file" "друкувати все у файл")
("print buffer" "буфер друку")
("print buffer to file" "друкувати буфер у файл")
("printer" "принтер")
("printer dpi" "роздільна здатність принтера (dpi)")
("printer dpi:" "роздільна здатність принтера (dpi):")
("printer setup" "налаштування принтера")
("printing command" "команда друку")
("printing command:" "команда друку:")
("print page selection" "друкувати обрані сторінки")
("print page selection to file" "друкувати обрані сторінки у файл")
("print the current buffer" "Друкувати поточний буфер")
("print to file" "друкувати у файл")
("print to postscript file" "друкувати у постскриптовий файл")
("problem" "проблема")
("Proceed" "Продовжити")
("produce cleaner LaTeX for @x for use with MathJax, pass 1" "Створює чистіший LaTeX для @x для використання з MathJax, прохід 1")
("produce cleaner LaTeX for @x for use with MathJax, pass 2" "Створює чистіший LaTeX для @x для використання з MathJax, прохід 2")
("produce Pdf using native export filter" "створити Pdf за допомогою вбудованого фільтра експорту")
("Produce Pdf using native export filter" "Створювати PDF використовуючи рідний експортний фільтр")
("produce Postscript using native export filter" "створити Postscript за допомогою вбудованого фільтра експорту")
("produce the string representation of a tmlength object." "Створити рядкове представлення обʼєкта tmlength.")
("professional" "професійний")
("prog" "програмний")
("prog font" "програмний шрифт")
("prog font family" "сімейство програмних шрифтів")
("prog font series" "серія програмних шрифтів")
("prog font shape" "форма програмного шрифту")
("program" "програма")
("program bracket matching" "відповідність дужок програми")
("program bracket selections" "вибір програмних дужок")
("program commands" "програмні команди")
("program font" "шрифт програми")
("program interface for buffer management" "інтерфейс програми для управління буфером")
("programming" "програмування")
("programming routines for editing documents" "програмні рутина для редагування документів")
("program mode" "програмний режим")
("progressive" "прогресивний")
("project" "проект")
("projects" "проекти")
("prologue" "пролог")
("prominent" "чільне")
("promise that the languages @lans are defined in the module @m" "Обіцяти, що мови @lans визначені в модулі @m")
("promise widgets" "Обіцянка віджетів")
("prompt on scripts" "запитувати про скрипти")
("prompts and default input" "підказки та введення за замовчуванням")
("proof" "доказ")
("proportional" "пропорційний")
("proportional typewriter" "пропорційна друкарська машинка")
("proposition" "пропозиція")
("provide the completions for @root as needed by custom-complete" "Надати завершення для @root, як потрібно для custom-complete")
("provoke C++ error" "спровокувати помилку C++")
("provoke menu error" "спровокувати помилку меню")
("provoke scheme error" "спровокувати помилку схеми")
("pseudo:" "псевдо:")
("pseudo code" "псевдокод")
("public key encryption" "шифрування з відкритим ключем")
("public keys" "відкриті ключі")
("pulse" "пульс")
("qt GUI only, sorry. Use \"Export selection\"" "лише графічний інтерфейс qt, вибачте. Використовуйте «Експорт вибору»")
("qt-widgets" "qt-віджети")
("quantifier" "кількісний показник")
("quasi" "квазі")
("query replace" "замінити з підтвердженням")
("question" "питання")
("questions only" "лише питання")
("questions with answers" "питання з відповідями")
("quick evaluation of formulas" "швидка оцінка формул")
("quit" "вийти")
("quotation" "цитата")
("quote" "цитувати")
("raise tformat tags in rows and cells of @t to the upmost level" "Підняти теги tformat в рядках та комірках @t до найвищого рівня")
("range" "діапазон")
("rank" "ранг")
("raw" "сирий")
("really close it" "дійсно закрити його")
("really delete user identity" "дійсно видалити ідентифікацію користувача")
("really delete user identity?" "дійсно видалити ідентифікацію користувача?")
("really huge" "дійсно величезний")
("really quit" "дійсно вийти")
("really tiny" "дійсно дрібний")
("(Re)Build autocompletion index" "(Повторно) Побудувати індекс автозаповнення")
("rebuild translations file" "перебудувати файл перекладів")
("rebuild translations file adding the missing ones (up to now)" "Перебудувати файл перекладів, додавши відсутні (до цього моменту)")
("recent" "останні")
("recent documents" "останні документи")
("recipients" "одержувачі")
("recognize" "визнати")
("recolor:" "переколірити:")
("recolor" "перефарбувати")
("recover autosave file" "відновити файл автоматичного збереження")
("rectangular" "прямокутний")
("recursively group matching brackets in concatenation @l." "Рекурсивно групувати відповідні дужки в конкатенації @l.")
("red" "червоний")
("reddish" "червонуватий")
("redo" "повернути")
("redo undone changes" "повернути скасовані зміни")
("reduce" "зменшити")
("reduce bottom margin by" "зменшити нижнє поле на")
("reduced margins" "зменшені поля")
("reduce left margin by" "зменшити ліве поле на")
("reduce margins" "зменшити поля")
("reduce right margin by" "зменшити праве поле на")
("reduce top margin by" "зменшити верхнє поле на")
("reduce trigonometric functions" "зменшити тригонометричні функції")
("reduction even page margin" "зменшення полів парних сторінок")
("reduction odd page margin" "зменшення полів непарних сторінок")
("reduction page bottom margin" "зменшення нижнього поля сторінки")
("reduction page right margin" "зменшення правого поля сторінки")
("reduction page top margin" "зменшення верхнього поля сторінки")
("reference" "посилання")
("reference guide" "довідковий посібник")
("reference guide for the standard TeXmacs styles" "довідковий посібник для стандартних стилів TeXmacs")
("reference guide for the TeXmacs primitives" "довідковий посібник для примітивів TeXmacs")
("references" "посилання")
("reference to note" "посилання на примітку")
("regenerate" "відновити")
("register extern loci listed in @t at url @here" "Зареєструвати зовнішні локуси, перераховані в @t за адресою @here")
("register file" "реєстраційний файл")
("regular" "регулярний")
("reinitialize wallet" "Переініціалізувати гаманець")
("relate" "відносити")
("relation" "відношення")
("release" "версія")
("release left button: finish editing" "відпустити ліву кнопку: завершити редагування")
("reload" "перечитати")
("remark" "зауваження")
("remote" "віддалений")
("remote:" "віддалений:")
("remote connections" "віддалені зʼєднання")
("remote control" "дистанційне керування")
("remote controllers with keyboard simulation" "дистанційні контролери з імітацією клавіатури")
("remote destination:" "віддалений призначення:")
("remote directory" "віддалений каталог")
("remote servers" "віддалені сервери")
("remote source:" "віддалене джерело:")
("remote tool" "віддалений інструмент")
("remove" "видалити")
("remove all implied packages in package list @ps" "Видаляє всі пакети, що включаються в список пакетів @ps")
("remove all links from the current locus." "Видалити всі посилання з поточного місця.")
("remove all links of type @type." "Видалити всі посилання типу @type.")
("remove all output fields" "видалити всі вихідні поля")
("remove banner" "видалити банер")
("remove database entry" "видалити запис з бази даних")
("removed entries from database" "видалено записи з бази даних")
("removed entry from database" "видалено запис з бази даних")
("remove downwards" "видалити вниз")
("remove entries" "видалити записи")
("remove entries in @l from keyboard mapping" "Видалити записи з @l з картографування клавіатури")
("remove entry" "видалити запис")
("remove field above" "видалити поле вище")
("remove field below" "видалити поле нижче")
("remove fields" "видалити поля")
("remove folded" "видалити згорнуте")
("remove input field" "видалити поле введення")
("remove input field above" "видалити поле введення вище")
("remove last field" "видалити останнє поле")
("remove leftwards" "видалити вліво")
("remove link" "видалити посилання")
("remove next field" "видалити наступне поле")
("remove number" "видалити номер")
("remove package" "видалити пакет")
("remove previous field" "видалити попереднє поле")
("remove rightwards" "видалити вправо")
("remove selected database entries" "видалити вибрані записи бази даних")
("remove selected entries" "видалити вибрані записи")
("remove superfluous invisible operators" "видалити зайві невидимі оператори")
("remove tag" "видалити тег")
("remove this branch" "видалити цю гілку")
("remove this switch" "вилучити цей перемикач")
("remove unfolded" "видалити розгорнуте")
("remove upwards" "видалити вгору")
("rename" "перейменувати")
("rename section" "перейменувати розділ")
("rendering" "вимальовування")
("rendering options for tag" "опції вимальовування для тегу")
("renumber this page" "перенумерувати цю сторінку")
("repeat" "повторити")
("repeat:" "повторити:")
("repeat object" "повторити обʼєкт")
("replace" "замінити")
("replace: " "замінити: ")
("replace all further occurrences" "замінити всі подальші випадки")
("replace by" "замінити на")
("replaced" "замінено")
("replaced one occurrence" "замінити один раз")
("replace one occurrence" "замінити один випадок")
("replace TeXmacs styles with no LaTeX equivalents" "замінити стилі TeXmacs без еквівалентів LaTeX")
("replace the contents of all loci with identifier @id by @t." "Замінити вміст всіх локусів з ідентифікатором @id на @t.")
("replace toolbar" "замінити панель інструментів")
("replace unrecognized styles" "замінити нерозпізнані стилі")
("research papers" "наукові роботи")
("reset" "переустановити")
("Reset" "Скинути")
("reset error counters" "скинути лічильники помилок")
("resize" "змінити розмір")
("resized" "змінений розмір")
("resize object" "змінити розмір обʼєкта")
("resize objects" "змінити розмір обʼєктів")
("resize the widget" "Змінити розмір віджета")
("restart in order to let the new look and feel take effect" "перезапустіть, щоб новий вигляд і відчуття набрали чинності")
("restart TeXmacs in order to let changes take effect" "перезапустіть TeXmacs, щоб зміни набрали чинності")
("retain" "зберегти")
("retime" "синхронізувати")
("retina settings" "налаштування ретиної")
("retrieved contents" "отриманий вміст")
("retrieve email" "отримати електронну пошту")
("retrieve key data from fingerprint @t" "Отримати дані ключа з відбитку @t")
("retrieve list of tags similar to @lab" "Отримати список тегів, схожих на @lab")
("retrieve list of variants of @lab" "Отримати список варіантів @lab")
("retrieve remote live document" "отримати віддалений живий документ")
("retrieve the current cursor position relative to the tree @t." "Отримати поточну позицію курсора відносно дерева @t.")
("retrieve user id from fingerprint @t" "Отримати ідентифікатор користувача з відбитку @t")
("retrieve wallet passphrase automatically at login?" "автоматично отримувати фразу-пароль гаманця при вході?")
("return" "повернутися")
("return active ancestor trees for the tree @t." "Повернути активні дерева-предки для дерева @t.")
("return a document with the documentation for macro @key" "Повертає документ з документацією для макросу @key")
("return a document with the scheme documentation for @key" "Повертає документ з документацією зі схеми для @key")
("return all submodules, recursively, for module list @ml" "Повертає всі підмодулі рекурсивно для списку модулів @ml")
("return calc-table ancestor for @t or #f" "Повертає предка calc-table для @t або #f")
("return list of identifiers in @l which admit an active link." "Повернути список ідентифікаторів в @l, які допускають активне посилання.")
("return locations of extern loci accessible from @t at url @here" "Повернути місця зовнішніх локусів, доступних з @t за адресою @here")
("return necessary catcode definitions for @doc" "Повертає необхідні визначення catcode для @doc")
("return necessary macro and environment definitions for @doc" "Повертає необхідні визначення макросів та середовищ для @doc")
("returns the (cached) name of the bibliography file" "Повертає (кешоване) імʼя файлу бібліографії")
("returns the (cached) style of the bibliography" "Повертає (кешований) стиль бібліографії")
("returns the list representation of a module given as a string" "Повертає список, що представляє модуль, заданий як рядок")
("returns the path to the dictionary file for @language" "Повертає шлях до файлу словника для @language")
("returns the word under the cursor, delimited by char-set:stopmark" "Повертає слово під курсором, обмежене char-set:stopmark")
("return the list of words below the given p-tree node @pt" "Повернути список слів нижче заданого вузла p-дерева @pt")
("return the number of columns of the row @r" "Повернути кількість стовпців рядка @r")
("return the number of columns of the table @t" "Повернути кількість стовпців таблиці @t")
("return the number of rows of the table @t" "Повернути кількість рядків таблиці @t")
("return the unique identifier of the locus @t or #f." "Повернути унікальний ідентифікатор локусу @t або #f.")
("return the usepackage command for @doc" "Повертає команду usepackage для @doc")
("retype passphrase:" "повторіть пароль:")
("re-typeset and render the tree @(tree-ref t . l)" "Перетипографувати та відобразити дерево @(tree-ref t . l)")
("reverse" "зворотний")
("reverse ordering" "зворотне замовлення")
("revert" "повернути")
("revert buffer" "відновити буфер")
("revert preference @which to default setting" "Повернути налаштування @which до значення за замовчуванням")
("rewrite weak left and write tabs in concatenation @l." "Переписати слабку ліву і записати вкладки в конкатенацію @l.")
("ridged paper" "рельєфний папір")
("right" "правий")
("right:" "право:")
("right aligned" "правий вирівняний")
("right arrow" "стрілка вправо")
("right baseline" "права базова лінія")
("right border" "правий край")
("right cell border" "права межа комірки")
("right cell padding" "права відступ комірки")
("right down" "вправо вниз")
("right margin:" "права межа:")
("right margin" "праве поле")
("right on even pages" "справа на парних сторінках")
("right padding" "праве заповнення")
("right subscript" "правий нижній індекс")
("right superscript" "правий верхній індекс")
("right surrounding" "праве оточення")
("right table border" "права межа таблиці")
("right table padding" "права відступ таблиці")
("right up" "вправо вгору")
("rightwards" "вправо")
("rigid" "жорсткий")
("rigid box" "жорстка коробка")
("rigid horizontal" "жорсткий горизонтальний")
("rigid space" "жорсткий проміжок")
("romanian" "румунська")
("root" "корінь")
("rotate" "повернути")
("rotate backward" "повернути назад")
("rotate forward" "повернути вперед")
("rotate objects" "повернути обʼєкти")
("rough" "грубий")
("rough paper" "грубий папір")
("round" "округлити")
("round overbrace" "кругла перенапруга")
("round underbrace" "круглий підвісок")
("row" "рядок")
("row above" "рядок вище")
("row below" "рядок внизу")
("row contains glued items" "рядок містить склеєні елементи")
("rows:" "рядки:")
("rows" "рядків")
("run" "виконати")
("run all regression tests in directory @u." "Виконати всі тестування на регресію в каталозі @u.")
("run current file" "запустити поточний файл")
("runic" "рунічний")
("running author" "біжучий автор")
("running title" "біжучий заголовок")
("russian" "російська")
("russian and Ukrainian users" "користувачі з кириличною абеткою")
("same names" "однойменних імен")
("same screen margins as on paper" "ті ж поля екрану, що і на папері")
("sample" "зразок")
("sample text" "зразок тексту")
("sans serif" "без засічок")
("sans serif:" "без засічок:")
("save" "зберегти")
("save as" "зберегти як")
("save as LaTeX" "зберегти як LaTeX")
("save as TeX" "зберегти як TeX")
("save auxiliary data" "зберегти допоміжні дані")
("save buffer" "зберегти буфер")
("save buffer as" "зберегти буфер як")
("saved" "збережений")
("saved modifications in database" "збережені зміни в базі даних")
("save entries" "зберегти записи")
("save entry" "зберегти запис")
("save file" "зберегти файл")
("save html file" "зберегти html файл")
("save image" "зберегти зображення")
("save image as" "зберегти зображення як")
("save latex file" "зберегти latex файл")
("save position" "зберегти позицію")
("save remote file" "зберегти віддалений файл")
("save tex file" "зберегти tex файл")
("save TeXmacs file" "зберегти файл TeXmacs")
("save TeXmacs style file" "зберегти файл стилю TeXmacs ")
("save this buffer" "зберегти цей буфер")
("save verbatim file" "зберегти буквальний файл")
("scale graphical interface:" "масштаб графічного інтерфейсу:")
("scale of the graphical user interface:" "масштаб графічного інтерфейсу:")
("scheme command" "командна схема")
("scheme developers guide" "Посібник для розробників схем")
("scheme extensions" "розширення схеми")
("scheme interface for the graphical mode" "Інтерфейс схеми для графічного режиму")
("screen" "екран")
("screen layout" "розміщення на екрані")
("screen margins" "екранні поля")
("screen rendering" "візуалізація екрана")
("screens" "екранів")
("screenshot" "скріншот")
("script" "індекс")
("script above" "індекс зверху")
("script below" "індекс знизу")
("scripting language:" "мова скриптів:")
("scripting language" "сценарій мови")
("scripts" "сценарії")
("script script size" "розмір індексу у індексі")
("script size" "розмір індексу")
("scripts not accepted" "скрипти не приймаються")
("search: " "пошук: ")
("search:" "пошук:")
("search" "шукати")
("search and replace" "пошук і заміна")
("search in documentation. Secure routine to use in ʼaction tags." "Пошук у документації. Безпечна процедура для використання в ʼaction tagsʼ.")
("searching" "пошук")
("search results for" "результати пошуку для")
("search toolbar" "панель інструментів пошуку")
("search upwards from the cursor position." "Шукати вгору від позиції курсора.")
("search words in my documents" "пошукові слова в моїх документах")
("search words in the documentation" "пошукові слова в документації")
("search words in the source code" "пошукові слова у джерельному коді")
("second:" "другий:")
("second" "секунда")
("secondary" "другорядний")
("secret keys" "секретні ключі")
("section" "розділ")
("sections" "розділів")
("security" "безпека")
("security:" "безпека:")
("see" "дивись")
("see documentation" "див. Документацію")
("select a document style" "виберіть стиль документа")
("select a foreground color" "виберіть колір")
("select a language" "виберіть мову")
("select a video" "Виберіть відео")
("selected region" "виділена область")
("selection" "відмітка")
("selections" "відмітки")
("select pen" "ручка вибору")
("selects word @w in tree @t, more or less around column @col." "Вибирає слово @w в дереві @t, більш-менш навколо стовпця @col.")
("select the action to be undertaken for each conflict" "виберіть дії, які слід здійснити для кожного конфлікту")
("select the tree @(tree-ref t . l)" "Вибрати дерево @(tree-ref t . l)")
("select view mode" "вибрати режим перегляду")
("semantic correctness" "смислова правильність")
("semantic editing" "семантичне редагування")
("semantics" "семантика")
("semantic selections" "смислові виділення")
("seminar" "семінар")
("sending commands to TeXmacs" "надсилання команд TeXmacs")
("senior" "старший")
("sep" "розд")
("separation between lines" "відстань між рядками")
("separation between paragraphs" "відстань між параграфами")
("separator" "роздільник")
("september" "вересень")
("serb" "серб")
("serialize a LaTeX preamble @t" "Серіалізує преамбулу LaTeX @t")
("series" "серія")
("series|right" "серія|право")
("serif" "сериф")
("serif:" "сериф:")
("server" "сервер")
("server:" "сервер:")
("session" "сесія")
("session commands" "сеансові команди")
("session name" "імʼя сесії")
("sessions" "сесії")
("session type" "тип сесії")
("set" "встановити")
("set a subtree of @t to a new value according to @l." "Встановити піддерево @t на нове значення згідно з @l.")
("set background color of cell" "встановити колір тла комірки")
("set background color of cell." "Встановити фоновий колір комірки.")
("set cell height." "Встановити висоту комірки.")
("set cell mode" "встановити режим комірки")
("set cell width." "Встановити ширину комірки.")
("set cell wrapping mode." "Встановити режим перенесення комірки.")
("set component @nr of a link to an url @name." "Встановити компонент @nr посилання на url @name.")
("set component @nr of a link to a @script." "Встановити компонент @nr посилання на @script.")
("set default" "встановити за замовчуванням")
("set default key fingerprint" "Встановити відбиток за замовчуванням ключа")
("set difference" "задана різниця")
("set extension center" "встановити центр розширення")
("set GnuPG cipher algorithm for passphrase encryption" "Встановити алгоритм шифрування GnuPG для зашифрування паролем")
("set GnuPG executable" "Встановити виконуваний файл GnuPG")
("set height" "встановити висоту")
("set height of cell" "встановити висоту комірки")
("set horizontal cell alignment." "Встановити горизонтальне вирівнювання комірки.")
("set horizontal table alignment." "Встановити горизонтальне вирівнювання таблиці.")
("set intersection" "встановити перехрестя")
("set locus number @nr of a link." "Встановити номер місця посилання @nr.")
("set margins" "встановити поля")
("set maximal cell height." "Встановити максимальну висоту комірки.")
("set maximal cell width." "Встановити максимальну ширину комірки.")
("set maximal table height." "Встановити максимальну висоту таблиці.")
("set maximal table width." "Встановити максимальну ширину таблиці.")
("set minimal cell height." "Встановити мінімальну висоту комірки.")
("set minimal cell width." "Встановити мінімальну ширину комірки.")
("set minimal table height." "Встановити мінімальну висоту таблиці.")
("set minimal table width." "Встановити мінімальну ширину таблиці.")
("set n" "встановити n")
("set number of columns" "встановити кількість стовпців")
("set number of rows" "встановити кількість рядків")
("set or get environment variables" "встановити або отримати змінні середовища")
("set paragraph margins" "встановити поля параграфу")
("set paragraph mode" "встановити режим параграфу")
("set preference @which to @what" "Встановити налаштування @which на @what")
("set printer dpi" "встановити роздільну здатність принтера (dpi)")
("set printing command" "встановити команду друку")
("set properties" "встановити властивості")
("set span" "встановити пропуск")
("set special cell properties" "встановити спеціальні властивості комірки")
("set special table properties" "встановити спеціальні властивості таблиці")
("sets the upper-left cell of a selection to span all of it" "Встановлює верхню ліву комірку вибору, щоб вона охоплювала всю його площу")
("set table height." "Встановити висоту таблиці.")
("set table width." "Встановити ширину таблиці.")
("set target of link to an @url." "Встановити ціль посилання на @url.")
("set target of link to a @script." "Встановити ціль посилання на @script.")
("set text width" "встановити ширину тексту")
("set the current linking mode to @mode" "Встановити поточний режим посилання на @mode")
("set the horizontal alignment of the marginal note to @ha." "Встановити горизонтальне вирівнювання примітки на полях на @ha.")
("set the horizontal position of the marginal note to @hp." "Встановити горизонтальне положення примітки на полях на @hp.")
("set the indentation of @s to @i spaces" "встановити відступ @s на @i пробілів")
("set the indentation of the current line to @i spaces" "встановити відступ поточного рядка на @i пробілів")
("set the mode for document part selections" "Встановити режим вибору частини документа")
("set the number of columns of the table to @nr." "Встановити кількість стовпців таблиці на @nr.")
("set the number of rows of the table to @nr." "Встановити кількість рядків таблиці на @nr.")
("set the vertical alignment of the marginal note to @va." "Встановити вертикальне вирівнювання примітки на полях на @va.")
("settings" "налаштування")
("set union" "встановити союз")
("setup printer" "налаштувати принтер")
("set user information" "встановити інформацію про користувача")
("set versioning grain." "Встановити рівень версіонування.")
("set vertical cell alignment." "Встановити вертикальне вирівнювання комірки.")
("set vertical correction mode for cell." "Встановити режим вертикальної корекції для комірки.")
("set vertical table alignment." "Встановити вертикальне вирівнювання таблиці.")
("set width" "встановити ширину")
("set width of cell" "встановити ширину комірки")
("seventh" "сьомий")
("seventh:" "сьомий:")
("several equations" "кілька рівнянь")
("shadow" "тінь")
("shadowed" "тіньовий")
("shadowed raise" "тіньовий підйом")
("shape" "форма")
("shift" "зміна")
("shift-down" "shift-вниз")
("shift-right" "shift-вправо")
("short" "короткий")
("shortcut" "швидкий доступ")
("show" "показати")
("show all parts" "показати всі частини")
("show current focus" "показати поточний фокус")
("show full context" "показати весь контекст")
("show header and footer" "показати заголовок і підвал")
("show hidden" "показати приховане")
("show key presses" "показати натискання клавіш")
("show main document" "показати основний документ")
("show memory usage" "показати використання памʼяті")
("show one part" "показати одну частину")
("show on screen" "показати на екрані")
("show panorama" "показати панораму")
("show preamble" "показати преамбулу")
("show several parts" "показати кілька деталей")
("show subunits" "показати субодиниці")
("show table cells" "показати клітинки таблиці")
("show the document part with name @id" "Показати частину документа з імʼям @id")
("show timings" "показати таймінги")
("shrinking factor" "фактор стиснення")
("side tools" "бічні інструменти")
("signature" "підпис")
("simple" "простий")
("simplification" "спрощення")
("simplified evaluation of formulas" "спрощена оцінка формул")
("simplified menus" "спрощені меню")
("simplify" "спростити")
("sine" "синус")
("sixth" "шостий")
("sixth:" "шостий:")
("size" "розмір")
("size:" "розмір:")
("size limits" "межі розміру")
("size tag" "розмір тегів")
("skew" "косий")
("skin" "шкіра")
("skin:" "шкіра:")
("skip all" "пропустити все")
("slant" "косий")
("slant:" "нахил:")
("slanted" "нахилений")
("slashed fraction" "розрізана частка")
("slides" "слайдів")
("sloppy" "недбалий")
("slovak" "словацька")
("slovene" "словенська")
("slow" "повільний")
("slow decrease" "повільне зменшення")
("slow increase" "повільне зростання")
("small" "маленький")
("small capitals" "малі капіталізовані літери")
("small capitals:" "малі капітальні літери:")
("small caps" "малі заголовні")
("small environment box" "невелика коробка навколишнього середовища")
("small figure" "маленький малюнок")
("small focus" "малий фокус")
("small inline" "маленький вбудований")
("small inline fraction" "мала вбудована частка")
("small skip" "маленький пропуск")
("small table" "маленька таблиця")
("smash" "удар")
("smooth" "гладкий")
("smooth end" "гладкий кінець")
("smooth extremities" "гладкі кінцівки")
("smooth start" "плавний старт")
("snap" "привʼязка")
("snap distance" "відстань привʼязки")
("snap to curves" "привʼязка до кривих")
("snap to grid" "привʼязка до сітки")
("snap to grid curve" "привʼязка до кривої сітки")
("snap to intersections of curves" "привʼязка до перетинів кривих")
("snap to pages" "привʼязка до сторінок")
("snap to text borders" "привʼязка до меж тексту")
("snap to text corners" "привʼязка до кутів тексту")
("solution" "рішення")
("solutions" "рішення")
("solution to exercise" "рішення вправи")
("solution to problem" "рішення проблеми")
("sound" "звук")
("source" "джерело")
("source code" "джерельний код")
("source directory:" каталог джерела:")
("source macros tool" "інструмент джерел макросів")
("source tags" "джерельні теги")
("south" "південь")
("south east" "південний схід")
("space" "пробіл")
("space bar in math mode:" "пробіл в математичному режимі:")
("space bar in math mode" "пробіл у математичному режимі")
("space bar in text mode:" "пробіл в текстовому режимі:")
("space bar in text mode" "пробіл у текстовому режимі")
("space between lines" "проміжок між рядками")
("space between paragraphs" "проміжок між абзацами")
("space stretchability:" "розтяжність пробілів:")
("space stretchability" "розтяжність простору")
("spacing" "інтервал")
("spacing:" "інтервали:")
("span" "проліт")
("spanish" "іспанська")
("span over all columns" "проміжок по всіх стовпцях")
("special" "особливий")
("special cell properties" "особливі властивості комірки")
("special functions" "спеціальні функції")
("special properties" "особливі властивості")
("special table properties" "особливі властивості таблиці")
("specific" "конкретний")
("specific baseline" "конкретна базова лінія")
("specify color alternation" "вказати чергування кольорів")
("specify how to traverse the manual" "вкажіть, як пройти інструкцію")
("specify semantics of a symbol or formula" "вкажіть семантику символу чи формули")
("specify the page setup" "Вказати налаштування сторінки")
("specify the size of the table" "вказати розмір таблиці")
("spell" "правопис")
("spell check" "перевірка орфографії")
("spell checking complete" "перевірка правопису завершена")
("spelling error" "помилка правопису")
("spelling errors have been corrected" "помилки правопису виправлені")
("spline" "сплайн")
("split" "розділити")
("split program" "розділена програма")
("split session" "розділений сеанс")
("square" "квадрат")
("square overbrace" "квадратний перебір")
("square root" "квадратний корінь")
("square underbrace" "квадратний підвісок")
("stack" "стек")
("standard" "стандарт")
("standard environment variables" "стандартні змінні середовища")
("standard formats" "стандартні формати")
("standard form for a simple function application" "Стандартна форма для простого застосування функції")
("standard fraction" "стандартна дробова частина")
("standard mathematical operators" "стандартні математичні оператори")
("standard Output" "стандартний вихід")
("standard TeXmacs styles" "стандартні стилі TeXmacs")
("star" "зірка")
("start" "початок")
("start a new chapter" "розпочати нову главу")
("start a new section" "розпочати новий розділ")
("start an interactive session" "розпочати інтерактивну сесію")
("start server" "запустити сервер")
("statement" "заява")
("statistics" "статистика")
("status" "статус")
("status bar" "рядок стану")
("stop server" "зупинити сервер")
("storage" "сховище")
("store tracking information in LaTeX files" "зберігати інформацію про відстеження у файлах LaTeX")
("stretch" "розтягнення")
("stretch:" "розтягнення:")
("stretchable" "розтяжний")
("stretchable horizontal" "розтяжний горизонтальний")
("stretchable vertical" "розтяжний вертикальний")
("stretched" "розтягнутий")
("stretch factor" "коефіцієнт розтягування")
("strict Ascii" "строгий ASCII")
("strike through" "закреслений")
("stroke" "промальовка")
("strokes" "промальовки")
("strong" "сильний")
("structural" "структурний")
("structured insert above" "структурована вставка зверху")
("structured insert at the left" "структурована вставка зліва")
("structured insert at the right" "структурована вставка справа")
("structured insert below" "структурована вставка знизу")
("structured remove downwards" "структуроване видалення вниз")
("structured remove leftwards" "структуроване видалення зліва")
("structured remove rightwards" "структуроване видалення справа")
("structured remove upwards" "структуроване видалення вгору")
("structured variant" "структурований варіант")
("structure tabs in concatenation @l." "Структурувати вкладки в конкатенації @l.")
("style" "стиль")
("style:" "стиль:")
("style options" "варіанти стилю")
("style parameters" "параметри стилю")
("styles" "стилі")
("stylesheet language" "мова таблиці стилів")
("sub" "під")
("subject" "тема")
("subject:" "тема:")
("submenu" "підменю")
("subparagraph" "підпараграф")
("subscript" "нижній індекс")
("subscript below" "підписка знизу")
("subsection" "підрозділ")
("subsub" "підпід")
("subsubmenu" "підпідменю")
("subsubsection" "підпідрозділ")
("subsubsubmenu" "підпідпідменю")
("subsubsubsubmenu" "підпідпідпідменю")
("subtable" "підтаблиця")
("subtitle" "підзаголовок")
("subtraction" "віднімання")
("summarized" "узагальнено")
("summary" "коротко")
("summary of the principal TeXmacs tags" "узагальнення основних тегів TeXmacs")
("superpose" "накладання")
("superposed" "накладений")
("superscript" "верхній індекс")
("superscript above" "верхній індекс зверху")
("supported plug-ins" "підтримувані плагіни")
("surface" "поверхня")
("surveys" "опитування")
("swedish" "шведська")
("swiss" "швейцарська")
("switch" "перемикач")
("switching and folding" "перемикання і складання")
("switch to buffer" "перехід до буфера")
("switch to first" "перемкнути на перший")
("switch to formula style" "переключитися на стиль формули")
("switch to last" "перемкнути на останній")
("switch to next" "перемкнути на наступний")
("switch to previous" "перемкнути на попередній")
("symbol" "символ")
("symbol properties not found" "властивості символу не знайдено")
("symbols" "символи")
("synchronize" "синхронізувати")
("synchronize bibliographic references" "синхронізувати бібліографічні посилання")
("synchronize with remote server" "синхронізувати з віддаленим сервером")
("synopsis" "конспект")
("syntax for a minimal test language" "синтаксис для мінімальної тестової мови")
("system command" "системна команда")
("system environment variables" "системні змінні середовища")
("tab" "вкладка")
("tabbed" "з вкладками")
("tab-completion" "заповнення вкладки")
("table" "таблиця")
("table breaking" "розбиття таблиці")
("table command" "таблична команда")
("table height" "висота таблиці")
("table of contents" "зміст")
("table properties" "властивості таблиці")
("tables" "таблиці")
("table width" "ширина таблиці")
("tabular" "табличний")
("tabular material" "табличний матеріал")
("tags with special rendering" "теги з особливим відображенням")
("tags with special rendering:" "теги з особливим відображенням:")
("tangent" "дотична")
("target" "ціль")
("tells if @data can be decrypted with passphrase @passphrase" "Вказує, чи можна розшифрувати @data з паролем @passphrase")
("tells if @fpr actually belongs to the public keyring" "Вказує, чи належить @fpr дійсно публічному ключовому кільцю")
("tells if @fpr actually belongs to the secret keyring" "Вказує, чи належить @fpr дійсно секретному ключовому кільцю")
("tells if GnuPG is available" "Вказує, чи доступний GnuPG")
("tells if @passphrase is correct" "Повідомляє, чи є правильним @passphrase")
("tells if passphrase @passphrase is correct for @fingerprint" "Вказує, чи є правильним пароль @passphrase для @fingerprint")
("tells if the platform provides a wallet implementation" "Повідомляє, чи надає платформа реалізацію гаманця")
("tells if wallet has been initialized" "Повідомляє, чи було ініціалізовано гаманець")
("tells if wallet is turned off" "Повідомляє, чи вимкнено гаманець")
("tells if wallet is turned on" "Повідомляє, чи ввімкнено гаманець")
("ternary" "трійковий")
("test" "тест")
("testing tree-view" "тестування дерева")
("test routine" "тестовий режим")
("teXmacs as an interface" "teXmacs як інтерфейс")
("teXmacs -> BibTeX" "teXmacs -> BibTeX")
("teXmacs buffer expected" "очікується буфер TeXmacs")
("teXmacs buffer on disk expected" "очікується буфер TeXmacs на диску")
("teXmacs DTD" "DTD TeXmacs")
("teXmacs extensions to scheme and utilities" "розширення TeXmacs для схеми та утиліт")
("teXmacs fonts" "шрифти TeXmacs")
("teXmacs -> Html" "teXmacs -> Html")
("teXmacs -> Image" "teXmacs -> Зображення")
("teXmacs -> LaTeX" "teXmacs -> LaTeX")
("teXmacs macro" "макрос TeXmacs")
("teXmacs manual" "керівництво TeXmacs")
("teXmacs notice" "примітки TeXmacs")
("teXmacs package" "пакет TeXmacs")
("teXmacs -> Pdf/Postscript" "teXmacs -> Pdf/Postscript")
("teXmacs plugins" "плагіни TeXmacs")
("teXmacs primitives" "примітиви TeXmacs")
("teXmacs style" "стиль TeXmacs")
("teXmacs style files" "файли стилю TeXmacs")
("teXmacs -> Verbatim" "teXmacs -> Verbatim")
("text" "текст")
("text borders" "межі тексту")
("text box style" "стиль текстового поля")
("text corners" "кути тексту")
("TeX" "TeX")
("tex" "tex")
("text font" "текстовий шрифт")
("text for note" "текст для примітки")
("textheight:" "висота тексту:")
("text height correction" "корекція висоти тексту")
("text height correction:" "корекція висоти тексту:")
("texts" "тексти")
("textual" "текстовий")
("textual operator" "текстовий оператор")
("textual spreadsheet" "текстова електронна таблиця")
("text width" "ширина тексту")
("text width:" "ширина тексту:")
("textwidth:" "ширина тексту:")
("thai" "тайська")
("th century bc" "століття до н.е.")
("the application did not send its usual startup banner" "додаток не відправив звичайний банер запуску")
("the application does not reply" "додаток не відповідає")
("the application is already running" "додаток вже запущено")
("the boxes produced by the typesetter" "бокси, створені верстатом")
("the document has not been saved" "документ не був збережений")
("the graphical user interface" "графічний інтерфейс користувача")
("the leaves of TeXmacs trees" "листки дерев TeXmacs")
("theme" "тема")
("theme parameters" "параметри теми")
("the mycas example" "приклад «mycas»")
("theorem" "теорема")
("the primitive TeXmacs constructs" "примітивні конструкції TeXmacs")
("there are unsaved documents" "є незбережені документи")
("these collected public keys will be definitely lost!" "ці зібрані публічні ключі будуть безповоротно втрачені!")
("these collected public keys will be definitely lost" "ці зібрані публічні ключі будуть безповоротно втрачені")
("these public keys will be definitely lost!" "ці публічні ключі будуть безповоротно втрачені!")
("these public keys will be definitely lost" "ці публічні ключі будуть безповоротно втрачені")
("these secret keys will be definitely lost!" "ці секретні ключі будуть безповоротно втрачені!")
("these secret keys will be definitely lost" "ці секретні ключі будуть безповоротно втрачені")
("the standard TeXmacs styles" "стандартні стилі TeXmacs")
("the TeXmacs authors" "автори TeXmacs")
("the TeXmacs format" "формат TeXmacs")
("the TeXmacs plug-in system" "система плагінів TeXmacs")
("thicken" "згустити")
("third" "третій")
("third:" "третій:")
("this" "цей")
("this column" "цей стовпець")
("this document has been produced using" "цей документ був створений за допомогою")
("this document has not been saved" "цей документ не був збережений")
("this line" "цей рядок")
("this page" "ця сторінка")
("this page footer" "нижній колонтитул цієї сторінки")
("this page header" "верхній колонтитул цієї сторінки")
("this page number" "номер цієї сторінки")
("this page number:" "номер цієї сторінки:")
("this row" "цей рядок")
("this style specifies page margins in the TeX way" "цей стиль визначає поля сторінок у стилі TeX")
("three columns" "три стовпці")
("three dots" "три крапки")
("th root" "корінь степеня")
("through popup windows" "через спливаючі вікна")
("through the menus" "через меню")
("thumbnails" "мініатюри")
("tilda" "тильда")
("tilde" "тильда")
("tile layout of widgets" "Розташування віджетів у формі плитки")
("time evolution" "еволюція часу")
("times" "помножити")
("timings" "часові параметри")
("tiny" "дуже малий")
("title" "заголовок")
("title:" "назва:")
("titled block" "заголовковий блок")
("title presentation options" "параметри презентації заголовка")
("title style" "стиль заголовка")
("title suffix" "суфікс заголовка")
("to" "до")
("today" "сьогодні")
("toggle:" "перемикач:")
("toggle a button using the mouse" "Перемкнути кнопку за допомогою миші")
("toggle cell wrapping mode" "перемикання режиму обгортання комірок")
("toggle cell wrapping mode." "Перемкнути режим перенесення комірки.")
("toggle evaluation mode." "Перемикає режим оцінки.")
("toggle full screen edit mode." "Перемкнути режим редагування на повному екрані.")
("toggle full screen mode." "Перемкнути повноекранний режим.")
("toggle here" "перемикач тут")
("toggle mathematical input in programs." "Перемикає математичний ввід у програмах.")
("toggle mathematical input in sessions." "Перемикає математичний ввід у сеансах.")
("toggle mode for determining margins from paragraph width." "Перемкнути режим визначення полів з ширини абзацу.")
("toggle mode for using a first indentation for each paragraph" "Перемкнути режим використання відступу для кожного абзацу")
("toggle mode for using reduced margins to save paper." "Перемкнути режим використання зменшених полів для економії паперу.")
("toggle mode for using special margins for screen editing." "Перемкнути режим використання спеціальних полів для редагування на екрані.")
("toggle mode for using standard page numbering" "Перемкнути режим використання стандартної нумерації сторінок")
("toggle multi-line input in programs." "Перемикає багаторядковий ввід у програмах.")
("toggle multi-line input in sessions." "Перемикає багаторядковий ввід у сеансах.")
("toggle off" "вимкнути")
("toggle on" "увімкнути")
("toggle output of evaluation timings." "Перемикає вивід часу оцінки.")
("toggle page snapping." "Перемкнути привʼязку до сторінки.")
("toggle panorama screen rendering." "Перемкнути режим панорамного відображення екрану.")
("toggle pretty math output in scheme programs." "Перемикає гарний вивід математики у схема програмах.")
("toggle pretty math output in scheme sessions." "Перемикає гарний вивід математики у схема сеансах.")
("toggle pretty scheme tree output in scheme programs." "Перемикає гарний вивід схеми дерева у схема програмах.")
("toggle pretty scheme tree output in scheme sessions." "Перемикає гарний вивід схеми дерева у схема сеансах.")
("toggle pretty tree output in scheme programs." "Перемикає гарний вивід дерева у схема програмах.")
("toggle pretty tree output in scheme sessions." "Перемикає гарний вивід дерева у схема сеансах.")
("toggle remote keyboard control mode." "Перемкнути режим дистанційного керування клавіатурою.")
("toggle scheme backtracing of errors." "Перемикання відстеження помилок схеми.")
("toggle source code editing mode." "Перемкнути режим редагування вихідного коду.")
("toggle table hyphenation." "Перемкнути перенесення слів в таблиці.")
("toggle the preamble mode for the document" "Перемкнути режим преамбули для документа")
("toggle the preference @which" "Перемкнути налаштування @which")
("toggle the search preference @which" "Перемкнути налаштування пошуку @which")
("toggle the visibility of the bottom tools." "Перемкнути видимість нижніх інструментів.")
("toggle the visibility of the document part with name @id" "Перемкнути видимість частини документа з імʼям @id")
("toggle the visibility of the @n-th icon bar." "Перемкнути видимість панелі іконок @n-го боку.")
("toggle the visibility of the @n-th side tools." "Перемкнути видимість бічних інструментів @n-го боку.")
("toggle the visibility of the windowʼs footer." "Перемкнути видимість нижнього колонтитула вікна.")
("toggle the visibility of the windowʼs header." "Перемкнути видимість заголовка вікна.")
("toggle using current buffer as master file of project." "Перемкнути використання поточного буфера як головного файлу проекту.")
("toggle visibility of headers and footers in ʼpageʼ paper mode." "Перемкнути видимість заголовків та підвалів у режимі ʼсторінкаʼ.")
("toggle whether loci are colored when rendering on paper." "Перемкнути, чи мають локуси кольори при відображенні на папері.")
("toggle whether we evaluate the innermost non-selected formulas." "Перемикає, чи оцінюємо найвнутрішніші невибрані формули.")
("toggle whether we generate link pages." "Перемкнути, чи генеруємо ми сторінки посилань.")
("toggle whether we keep the input of evaluations." "Перемикає, чи зберігаємо вхід оцінок.")
("toggle whether we may follow links defined in other loci." "Перемкнути, чи можемо ми слідувати посиланням, визначеним в інших локусах.")
("toggle whether we may follow links in both directions." "Перемкнути, чи можемо ми слідувати посиланням у обох напрямках.")
("toggle whether we may follow links of a given @type." "Перемкнути, чи можемо ми слідувати посиланням заданого @type.")
("toggle whether we save auxiliary data." "Перемкнути збереження допоміжних даних.")
("toggle whether we show keyboard presses." "Перемкнути показ натискання клавіш.")
("tolerant" "толерантний")
("tools" "інструменти")
("top" "верх")
("top:" "верх:")
("top baseline" "верхній базовий рівень")
("top border" "верхня межа")
("top cell border" "верхня межа клітинки")
("top cell padding" "верхня клітинка")
("top level" "верхній рівень")
("top margin" "верхнє поле")
("topmargin:" "верхня межа:")
("top padding" "верхнє відступання")
("top table border" "межа верхньої таблиці")
("top table padding" "підкладка верхнього столу")
("to the left" "вліво")
("to the right" "вправо")
("transform" "перетворення")
("transform a menu into a widget." "Перетворити меню в віджет.")
("transform cell into subtable" "перетворити клітинку в підтаблицю")
("transform negative indices in table format into positive ones" "Перетворити відʼємні індекси в формат таблиці на позитивні")
("transforms the link list @t into a navigation list" "Перетворити список посилань @t у список навігації")
("translate" "трансляція")
("translate a string with arguments" "Перекласти рядок з аргументами")
("translations" "переклади")
("translations loaded" "переклади завантажено")
("translations missing in the dictionary (up to now)" "Переклади, відсутні в словнику (до цього моменту)")
("transpose" "транспонувати")
("traversal" "обхідні")
("traverse" "обхід")
("tree" "дерево")
("triangle" "трикутник")
("triangularize" "триангуляція")
("trigonometric" "тригонометричний")
("trigonometry" "тригонометрія")
("try to export and LaTeX all TeXmacs files inside @u" "Спробувати експортувати та LaTeX всі файли TeXmacs всередині @u")
("try to import formulas using LaTeX annotations" "пробувати імпортувати формули використовуючи анотації LaTeX")
("tuple" "кортеж")
("turkish" "турецька")
("turn off" "вимкнути")
("turn on" "увімкнути")
("turn wallet off" "Вимкнути гаманець")
("turn wallet on using @passphrase" "Увімкнути гаманець, використовуючи @passphrase")
("tutorial" "навчальний посібник")
("tutorials" "навчальні посібники")
("two columns" "дві колонки")
("two dots" "дві крапки")
("type" "тип")
("type a latex command followed by" "введіть команду LaTeX, за якою слідує")
("type a latex command followed by return" "введіть команду LaTeX, а потім натисніть Enter")
("type body" "введіть тіло")
("type denominator" "введіть знаменник")
("type numerator" "введіть чисельник")
("type script" "введіть індекс")
("typesetted boxes" "набрані бокси")
("typewriter" "друкарська машинка")
("typewriter:" "машинний шрифт:")
("typewriter small caps" "малі заголовні літери на друкарській машинці")
("typing a simple text" "введення простого тексту")
("typing simple texts" "введення простих текстів")
("ugaritic" "угаритська")
("ukrainian" "українська")
("unchanged" "без змін")
("underbrace" "під-дужку")
("underline" "підкреслити")
("underlined" "підкреслено")
("undo" "скасувати")
("undo last changes" "скасувати останні зміни")
("unevaluated argument" "неоцінений аргумент")
("unevaluated value" "неоцінене значення")
("unfold" "розгорнути")
("unfold all" "розгорнути все")
("unfold all fields" "розгорнути всі поля")
("unfold using the mouse" "Розгорнути за допомогою миші")
("unit" "одиниця")
("unit length" "одиниця довжини")
("unknown secret key fingerprint" "невідомий відбиток секретного ключа")
("unold at the current focus position" "Розгорнути на поточній позиції фокусу")
("unregistered file" "незареєстрований файл")
("unroll" "розкрутити")
("unsecure script refused" "незахищений сценарій відхилено")
("unsupported link mode" "непідтримуваний режим звʼязку")
("until" "до")
("untitled block" "блок без назви")
("up" "вгору")
("up:" "вгору:")
("update" "оновити")
("update buffer" "оновити буфер")
("update buffer:" "оновити буфер:")
("update from web" "оновлення з Інтернету")
("update image links" "оновити посилання на зображення")
("update this buffer" "оновити цей буфер")
("update web site" "оновити веб-сайт")
("upight" "вертикальний")
("upload" "Завантажити")
("upload message:" "повідомлення завантаження:")
("upper border" "верхній край")
("upright" "вертикально")
("up to date" "актуально")
("upwards" "вгору")
("url of the cache with the collected macro documentation." "URL кешу зі зібраною документацією макросу.")
("url of the cache with the collected scheme documentation." "URL кешу зі зібраною документацією схеми.")
("use a black color" "використовувати чорний колір")
("use a blue color" "використовувати синій колір")
("use a bold font" "використовувати жирний шрифт")
("use a brown color" "використовувати коричневий колір")
("use a calligraphic font" "використовувати рукописний шрифт")
("use a green color" "використовувати зелений колір")
("use a grey color" "використовувати сірий колір")
("use a magenta color" "використовувати фіолетовий колір")
("use a orange color" "використовувати жовтогарячий колір")
("use a pink color" "використовувати рожевий колір")
("use a red color" "використовувати червоний колір")
("use a sans serif font" "використовувати шрифт без засічок")
("use as master" "використовувати як майстер")
("use a typewriter font" "використовувати шрифт друкарської машинки")
("use a white color" "використовувати білий колір")
("use a yellow color" "використовувати жовтий колір")
("use blackboard bold font" "використовувати шрифт blackboard bold")
("use bold font series" "використовувати серію жирних шрифтів")
("use calligraphical font" "використовувати рукописний шрифт")
("use CSS for more advanced formatting" "використовувати CSS для більш розширеного форматування")
("use extensible brackets" "використовувати розтяжні дужки")
("use footnote font size" "використовувати розмір шрифту для виносок")
("use fraktur font" "використовувати готичний шрифт")
("use high resolution icons:" "використовувати іконки високої роздільної здатності:")
("use huge font size" "використовувати величезний розмір шрифту")
("use Inkscape for conversion from SVG" "використовувати Inkscape для конвертації з SVG")
("use italic font shape" "використовувати курсивну форму шрифту")
("use large font size" "використовувати великий розмір шрифту")
("use left hand column as border" "використовувати лівий стовпець як межу")
("use line wrapping for lines which are longer than 80 characters" "використовувати перенесення рядків для ліній, які довше 80 символів")
("use margin kerning:" "використовувати вирівнювання по полях:")
("use margin kerning (protrusion)" "використовувати кернінг поля (виступ)")
("use MathML" "використовувати MathML")
("use medium font series" "використовувати серію середніх шрифтів")
("use native menubar" "використовувати вбудоване меню")
("use normal font size" "використовувати нормальний розмір шрифту")
("use package" "використовувати пакет")
("use paragraph width" "використовувати ширину абзацу")
("use print dialogue" "використовувати діалог друку")
("use protrusion" "використовувати виступ")
("user" "користувач")
("use really huge font size" "використовувати дійсно великий розмір шрифту")
("use relative path" "використовувати відносний шлях")
("use relative path:" "використовувати відносний шлях:")
("use retina fonts:" "використовувати шрифти retina:")
("use retina icons:" "використовувати іконки retina:")
("use right font shape" "використовувати пряму форму шрифту")
("use right hand column as border" "використовувати правий стовпець як межу")
("user interface" "інтерфейс користувача")
("user interface language" "мова інтерфейсу користувача")
("user interface language:" "мова користувацького інтерфейсу:")
("user interface theme" "тема інтерфейсу користувача")
("user interface theme:" "тема користувацького інтерфейсу:")
("user manual" "посібник користувача")
("use roman font family" "використовувати сімейство шрифтів roman")
("use row above as border" "використовувати верхній рядок як межу")
("use row below as border" "використовувати нижній рядок як межу")
("user preferences" "налаштування користувача")
("user provided icons" "іконки, надані користувачем")
("users of Cyrillic languages" "користувачі кирилицьких мов")
("users of oriental languages" "користувачі східних мов")
("user toolbar" "панель користувача")
("use sans serif font family" "використовувати сімейство шрифтів без засічок")
("use script font size" "використовувати розмір індексного шрифту")
("use slanted font shape" "використовувати похилу форму шрифту")
("use small capitals" "використовувати малі заголовні")
("use small-caps font shape" "використовувати форму шрифту малих заголовних")
("use small font size" "використовувати малий розмір шрифту")
("use TeXmacs" "використовувати TeXmacs")
("use the blackboard bold font" "використовувати шрифт blackboard bold")
("use the fraktur font" "використовувати готичний шрифт")
("use tiny font font size" "використовувати дрібний розмір шрифту")
("use typewriter font family" "використовувати сімейство шрифтів друкарської машинки")
("use unified toolbars" "використовувати обʼєднані панелі інструментів")
("use very large font size" "використовувати дуже великий розмір шрифту")
("utf-8 with inputenc LaTeX package" "utf-8 з пакетом inputenc LaTeX")
("utilities" "комунальні послуги")
("value" "значення")
("vanish" "зникнути")
("variable" "змінна")
("variant" "варіант")
("variant of tex-concat which concatenates adjacent strings" "Варіант tex-concat, який зʼєднує прилеглі рядки")
("vector" "вектор")
("verbatim" "буквально")
("verbatim -> TeXmacs" "verbatim -> TeXmacs")
("verbose" "розговірний")
("verse" "вірш")
("version" "версія")
("versioning tool" "інструмент для версіонування")
("vertical" "вертикальний")
("vertical:" "вертикально:")
("vertical after" "вертикально після")
("vertical alignment" "вертикальне вирівнювання")
("vertical before" "вертикально перед")
("vertical cell alignment" "вертикальне вирівнювання комірки")
("vertical layout of widgets" "Вертикальне розташування віджетів")
("vertically align cell to the base" "вертикально вирівняти комірку за базовим рівнем")
("vertically center the cell" "вертикально центрувати комірку")
("vertical margins" "вертикальні поля")
("vertical part" "вертикальна частина")
("vertical position" "вертикальне положення")
("vertical separator" "Вертикальний роздільник")
("vertical space" "вертикальний проміжок")
("vertical space after" "вертикальний простір після")
("vertical space before" "вертикальний простір до")
("vertical space stretchability" "вертикальна розтяжність простору")
("vertical space stretchability:" "розтяжність вертикального простору:")
("vertical table alignment" "вертикальне вирівнювання таблиці")
("very large" "дуже великий")
("very small" "дуже маленький")
("vietnamese" "вʼєтнамська")
("view" "вигляд")
("visible" "видимий")
("visible except here" "видимо, крім цього місця")
("visible from here on" "видно звідси і далі")
("visible only here" "видно лише тут")
("visible until here" "видно до цього місця")
("visited color" "колір відвіданого")
("visited loci" "відвідані локуси")
("vpos" "вертпоз")
("wallet" "гаманець")
("wallet:" "гаманець:")
("wallet passphrase:" "фраза-пароль гаманця:")
("warning" "попередження")
("warning: weak passphrase, click Ok again to confirm." "попередження: слабка фраза-пароль, натисніть ОК ще раз, щоб підтвердити.")
("wave" "хвиля")
("web" "веб")
("weight" "вага")
("weight:" "жирність:")
("welcome" "ласкаво просимо")
("welcome to GNU TeXmacs" "ласкаво просимо у GNU TeXmacs")
("what is new" "що нового")
("when finished" "коли закінчено")
("when line wrapping" "при обгортанні рядків")
("when primitive for content generation" "Коли примітив для генерації вмісту")
("while" "поки")
("white" "білий")
("whitespace" "пробіл")
("wide" "широкий")
("wide accent" "широкий акцент")
("wide bar" "широка лінія")
("wide block" "широкий блок")
("wide colored" "широкий кольоровий")
("wide float" "широкий плаваючий обʼєкт")
("wide footnote" "широка виноска")
("widescreen" "широкоекранний")
("wide tabular" "широка таблична")
("widget which is split horizontally into two parts" "Віджет, який розділяється горизонтально на дві частини")
("widget which is split vertically into two parts" "Віджет, який розділяється вертикально на дві частини")
("widget with CSS style name" "Віджет з імʼям стилю CSS")
("width" "ширина")
("width:" "ширина:")
("width is exactly the specified width" "ширина точно як задана")
("width is maximum of specified width and box width" "ширина більша з заданої і ширини бокса")
("width is minimum of specified width and box width" "ширина менша з заданої і ширини бокса")
("width magnification" "розтягання ширини")
("window" "вікно")
("window height" "висота вікна")
("windows key" "клавіша вікон")
("window width" "ширина вікна")
("with" "з")
("with primitive for content generation" "З примітивом для генерації вмісту")
("wrap lines" "обгортати рядки")
("write a macro" "написати макрос")
("write a name" "писати імʼя")
("write bold mathematics" "писати жирну математику")
("write bold text" "писати жирний текст")
("write italic text" "писати курсивний текст")
("write sample text" "писати приклад тексту")
("write strong text" "писати сильний текст")
("write typewriter text" "писати текст як на друкарській машинці")
("write verbatim text" "писати буквальний текст")
("writing data converters" "написання конвертерів даних")
("writing documentation" "написання документації")
("writing TeXmacs bibliography styles" "написання стилів бібліографії TeXmacs")
("writing your own style files" "написання ваших власних файлів зі стилями")
("written with TeXmacs" "написано з використанням TeXmacs")
("wrong empty passphrase" "неправильна порожня фраза-пароль")
("wrong passphrase" "неправильна фраза-пароль")
("xperiment" "експеримент")
("year" "рік")
("yellow" "жовтий")
("yes" "Так")
("you are attempting to open an encrypted file while" "Ви намагаєтесь відкрити зашифрований файл під час")
("you can also obtain" "ви також можете отримати")
("you might consider enabling the experimental" "Ви можете розглянути можливість включення експериментального")
("you must add a bibliography file" "Ви повинні додати файл бібліографії")
("your document is back in its original state" "ваш документ повернений у вихідний стан")
("your first interface" "ваш перший інтерфейс")
("your language" "ваша мова")
("your personal dictionary has been modified" "ваш особистий словник був змінений")
("you should also make sure that GnuPG is installed" "Ви також повинні переконатися, що GnuPG встановлено")
("zoom" "збільшення")
("zoom in" "збільшити")
("zoom out" "зменшити масштаб")
("conjecture" "гіпотеза")
("macro editor" "редактор макросів")
